/*
BugMon - By Scott Nance (snance@exmsft.com)

See help.html and/or widget.xml for Release History.

The genesis of BugMon came about after I played with David Dekker's BugzMonitor widget. I needed
flexability that it didn't provide and I wanted a quick way to learn JavaScript.  So I combined the two.
As I added more features and decided to migrate the widget to Konfab 4.0, I ended up doing a
ground-up rewrite and producing a new critter entirely.  Heck, even the graphics have been changed.

Thanks to David for a great starting idea.  I hope that this is something along the lines he'd have liked
to see the widget evolve.

Please let me know if you like this widget, have questions or functionality suggestions, or just want to say "Hi".
   -Scott (snance@exmsft.com)
*/

/* NOTE TO SELF: Version # is stored in the following places...
	widget.xml - <version>1.2</version>
	widget.xml - <description> - Revision History Section
	BugMon.kon - <widget version="1.2"
	BugMon.kon - <about-version>1.2</about-version>
	BugMon.kon - <preference name="LASTWARNEDVERSION"><defaultValue>1.2
	Resources/help.html - Main Title Line
	Resources/help.html - Revision History Section
*/

// Load the colors from prefs on first run
LoadColors();

// Check for new version on first run
CheckForNewVersion(0);

// Now run the program...
BugMon();

function BugMon()
{
	// Main Program Loop
	// stop the timer
	tmrRefresh.ticking = "false";

	// Define column sizes - percents must total 1, one max width must be set to -1 (this column will get all extra space)
	var intColWidthPercent = [];
	var intColWidthMax = [];
	intColWidthReal = [];
	intColWidthPercent[1] = 0.11;
	intColWidthMax[1] = 50;
	intColWidthPercent[2] = 0.8;
	intColWidthMax[2] = 45;
	intColWidthPercent[3] = 0.13;
	intColWidthMax[3] = 60;
	intColWidthPercent[4] = 0.13;
	intColWidthMax[4] = 60;
	intColWidthPercent[5] = 0.40;
	intColWidthMax[5] = -1;
	intColWidthPercent[6] = 0.15;
	intColWidthMax[6] = 80;

	// Set the interval of the refresh timer
	tmrRefresh.interval = intRefreshTime;

	// Resize the main window width to accomodate the displayed control
	mainWindow.width = intTotalWidth;
	mainWindow.shadow = true;

	// calc the apropriate column sizes - percentage up to maximum size,  all excess goes into -1 (flex-column)
	var intUsableTextWidth = intTotalWidth - 24;
	var intRemainder = intUsableTextWidth;

	var intFlexColumn = 0;
	for (var intLoopy = 1; intLoopy < intColWidthPercent.length; intLoopy++)
	{
	    intColWidthReal[intLoopy] = intUsableTextWidth * intColWidthPercent[intLoopy];
	    intColWidthReal[intLoopy] = parseInt(intColWidthReal[intLoopy], 10);
	    if (intColWidthMax[intLoopy] !== -1)
	    {
	        if (intColWidthReal[intLoopy] > intColWidthMax[intLoopy])
	        {
	            intColWidthReal[intLoopy] = intColWidthMax[intLoopy];
	        }
	        intRemainder = intRemainder - intColWidthReal[intLoopy];
	    }
	    else
	    {
	        intFlexColumn = intLoopy;
	    }
	}
	intColWidthReal[intFlexColumn] = intRemainder;

	// trim leading and trailing whitespace
	strBaseUrl = String(strBaseUrl.replace(/^\s+|\s+$/g,""));
	
	// clean up trailing slashes in base URL, if present
	strBaseUrl = String(strBaseUrl.replace(/\/\z/,""));
	
	// Show Prefs Header if server not set...
	if (strBaseUrl.length < 8)
	{
		ShowHeader("(Set Connection Options in Preferences...)", "");
	}
	else
	{	
		// Intially show the Refreshing Bugs header
		ShowHeader("(Refreshing Bug List...)", "");
	}

	// Build the customized header
	strAddDisplay = "(";
	var intPrevious = 0;
	if (strProduct.length > 0)
	{
	    strAddDisplay = strAddDisplay + "Product:" + strProduct;
	    intPrevious = 1;
	}
	if (strComponent.length > 0)
	{
	    if (intPrevious === 1)
	    {
	        strAddDisplay = strAddDisplay + ", ";
	    }
	    strAddDisplay = strAddDisplay + "Component:" + strComponent;
	    intPrevious = 1;
	}
	if (strVersion.length > 0)
	{
	    if (intPrevious === 1)
	    {
	        strAddDisplay = strAddDisplay + ", ";
	    }
	    strAddDisplay = strAddDisplay + "Version:" + strVersion;
	    intPrevious = 1;
	}
	if (strTargetMilestone.length > 0)
	{
	    if (intPrevious === 1)
	    {
	        strAddDisplay = strAddDisplay + ", ";
	    }
	    strAddDisplay = strAddDisplay + "Milestone:" + strTargetMilestone;
	    intPrevious = 1;
	}
	if (strSince > 0)
	{
	    if (intPrevious === 1)
	    {
	        strAddDisplay = strAddDisplay + ", ";
	    }
	    strAddDisplay = strAddDisplay + "Days:" + strSince;
	}
	if (strQueryString.length > 0)
	{
	    strAddDisplay = "(Custom Query String:" + strQueryString;
	}
	strAddDisplay = strAddDisplay + ")";
	if (strAddDisplay.length === 2)
	{
	    strAddDisplay = "";
	}

	// Build login query string
	var strLogin = "";
	if (strUser.length > 0)
	{
		strLogin = strLogin + "&Bugzilla_login=" + strUser;
	}
	if (strPassword.length > 0)
	{
		strLogin = strLogin + "&Bugzilla_password=" + strPassword;
	}
	if ((strUser.length == 0) && (strPassword.length == 0))
	{
		strLogin = "";
	}
	else
	{
		strLogin =  strLogin + "&submit=GoAheadAndLogIn";
	}

	// build query string for day limits
	var strQuerySince = "&chfield=%5BBug%20creation%5D&chfieldfrom=-" + strSince + "d";
	if ((parseInt(strSince, 10) === 0) || (strSince === null))
	{
		strQuerySince = "";
	}

	// build query string to limit to bugs assigned to me
	var strAssignmentLimit = "";
	if (parseInt(intAssignedToMe, 10) === 1)
	{
	    strAssignmentLimit = "&emailassigned_to1=1&emailtype1=substring&email1=" + strUser;
	}
	else
	{
	    strAssignmentLimit = "";
	}

	// build query strings for bug statuses
	var strShowStatus = "";
	if (parseInt(intShowUnconfirmed, 10) === 1)
	{
	    strShowStatus = "&bug_status=UNCONFIRMED";
	}
	if (parseInt(intShowNew, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=NEW";
	}
	if (parseInt(intShowAssigned, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=ASSIGNED";
	}
	if (parseInt(intShowReopened, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=REOPENED";
	}
	if (parseInt(intShowResolved, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=RESOLVED";
	}
	if (parseInt(intShowVerified, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=VERIFIED";
	}
	if (parseInt(intShowClosed, 10) === 1)
	{
	    strShowStatus = strShowStatus + "&bug_status=CLOSED";
	}

	// build the sorted by query string
	var strSortedBy = "";
	if (strSortedByPri.length > 0)
	{
		strSortedBy = strSortedByPri;
		if (String(intSortedByPriDesc) == "1")
		{
			strSortedBy = strSortedBy + "%20desc";
		}
	}
	if (strSortedBySec.length > 0)
	{
		strSortedBy = strSortedBy + "," + strSortedBySec;
		if (String(intSortedBySecDesc) == "1")
		{
			strSortedBy = strSortedBy + "%20desc";
		}
	}
	if (strSortedByTer.length > 0)
	{
		strSortedBy = strSortedBy + "," + strSortedByTer;
		if (String(intSortedByTerDesc) == "1")
		{
			strSortedBy = strSortedBy + "%20desc";
		}
	}

	// build query string for product
	var strProductQuery = "";
	if (strProduct.length > 0)
	{
	    strProductQuery = "&product=" + escape(strProduct);
	}
	
	// build query string for component
	var strComponentQuery = "";
	if (strComponent.length > 0)
	{
	    strComponentQuery = "&component=" + escape(strComponent);
	}
	
	// build query string for version
	var strVersionQuery = "";
	if (strVersion.length > 0)
	{
	    strVersionQuery = "&version=" + escape(strVersion);
	}
	
	// build query string for target milestone
	var strTargetMilestoneQuery = "";
	if (strTargetMilestone.length > 0)
	{
	    strTargetMilestoneQuery = "&target_milestone=" + escape(strTargetMilestone);
	}
	
	// load the Projects and Milestones for config screens
	urlInput = LoadUnicode(strBaseUrl + "/query.cgi?format=advanced" + strLogin);
	LoadAllOptions(urlInput);
	
	// Set the query for the bug list
	if (strQueryString === "")
	{
		preferences.SYSTEMQUERYSTRING.value = "?query_format=specific&order=" + strSortedBy + strShowStatus + strProductQuery + strComponentQuery + strVersionQuery + strTargetMilestoneQuery + strAssignmentLimit + strQuerySince;
	    strFullUrl = strBaseUrl + "/buglist.cgi" + preferences.SYSTEMQUERYSTRING.value + strLogin;
	}
	else
	{
	    strFullUrl = strBaseUrl + "/buglist.cgi" + strQueryString + strLogin;
	}
	
	// Load the bug list page
	urlInput = LoadUnicode(strFullUrl);
	
	// load the bugs into the display widget - return # of bugs found
	var intNumBugs = LoadBugs(urlInput);

	// add bug totals to beginning of header
	strAddDisplay = String(intNumBugs) + " Bugs " + strAddDisplay;

	// Show Prefs Header if server not set...
	if (strBaseUrl.length < 8)
	{
		ShowHeader("(Set Connection Options in Preferences...)", "");
	}
	else
	{	
		// Show the header
		ShowHeader(strAddDisplay, strFullUrl);
	}

	// restart the timer
	tmrRefresh.ticking = "true";

	// reset the refresh timer
	tmrRefresh.reset();

	// A little more paranoid cleanup before we end
	intColWidthPercent = [];
	intColWidthMax = [];
}

function LoadUnicode(strURL)
{
	// load the URL through a disk file if the pref is set - workaround for Konfabulator error in processing UTF-8 Unicode data
	var urlLookup = new URL();
	var strURLDataLoad = "";
	urlLookup.location = strURL;
	
	if (preferences.LOADUNICODE.value == 0)
	{
		// load quickly to memory
		urlLookup.fetch();
		strURLDataLoad = urlLookup.result;
	}
	else
	{
		// cycle through temp file to fix unicode issues
		urlLookup.outputFile = convertPathToPlatform(system.widgetDataFolder + "/temp.txt");
		urlLookup.fetch();
		try
		{
			strURLDataLoad = filesystem.readFile(urlLookup.outputFile);
		}
		catch(e)
		{
		}
		try
		{
			if (filesystem.itemExists(urlLookup.outputFile) == true)
			{
				filesystem.moveToTrash(urlLookup.outputFile);
			}
		}
		catch(e)
		{
		}
	}

	if (IsNull(strURLDataLoad) == true)
	{
		strURLDataLoad = "";
	}
	
	// BRUTALLY clear the Lookup URL (to prevent memory leaks)
	try
	{
		urlLookup.clear();
		urlLookup = null;
		delete urlLookup;
	}
	catch(err)
	{
		err = null;
	}
	return strURLDataLoad;
}

function Left(str, n)
{
	// return leftmost n characters of a string
	if (n <= 0)
    {
	    return "";
    }
	else if (n > String(str).length)
    {
	    return str;
    }
	else
    {
	    return String(str).substring(0,n);
    }
}

function Right(str, n)
{
	// return rightmost n characters of a string
	var iLen;
    if (n <= 0)
    {
        return "";
    }
    else if (n > String(str).length)
    {
        return str;
    }
    else
    {
        iLen = String(str).length;
        return String(str).substring(iLen, iLen - n);
    }
}

function Trim(strHeaderText)
{
	// trim leading and trailing whitespace
	return String(strHeaderText).replace(/^\s+|\s+$/g,"");
}

function IsDigit(strHeaderText)
{
	// return true if strHeaderText is a digit between 0 and 9
	var ValidChars = "0123456789";
	var IsNumber = true;
	var Char;
	var i;
	
	for (i = 0; i < strHeaderText.length && IsNumber === true; i++) 
	{  
		Char = strHeaderText.charAt(i); 
		if (ValidChars.indexOf(Char) === -1) 
		{
			IsNumber = false;
		}
	}
	return IsNumber;
}

function IsNull(varVariable)
{
	return(varVariable == null);
}

function HideBar(intSwatRow)
{
    // hide a row of objects - if they exist
	if (intSwatRow < 50)
    {
		imageBar1[intSwatRow].visible = false;
		imageBar2[intSwatRow].visible = false;
		imageBar3[intSwatRow].visible = false;
		imageBar4[intSwatRow].visible = false;
		imageBar5[intSwatRow].visible = false;
		imageBar6[intSwatRow].visible = false;
		imageBar1[intSwatRow].src = "";
		imageBar2[intSwatRow].src = "";
		imageBar3[intSwatRow].src = "";
		imageBar4[intSwatRow].src = "";
		imageBar5[intSwatRow].src = "";
		imageBar6[intSwatRow].src = "";
		imageBar1[intSwatRow].onMouseDown = null;
		imageBar2[intSwatRow].onMouseDown = null;
		imageBar3[intSwatRow].onMouseDown = null;
		imageBar4[intSwatRow].onMouseDown = null;
		imageBar5[intSwatRow].onMouseDown = null;
		imageBar6[intSwatRow].onMouseDown = null;
		textBar1[intSwatRow].visible = false;
		textBar2[intSwatRow].visible = false;
		textBar3[intSwatRow].visible = false;
		textBar4[intSwatRow].visible = false;
		textBar5[intSwatRow].visible = false;
		textBar6[intSwatRow].visible = false;
		textBar1[intSwatRow].data = null;
		textBar2[intSwatRow].data = null;
		textBar3[intSwatRow].data = null;
		textBar4[intSwatRow].data = null;
		textBar5[intSwatRow].data = null;
		textBar6[intSwatRow].data = null;
    }
}

function LoadAllOptions(urlData)
{
	// set TargetMilestone Preferences value
	preferences.TARGETMILESTONE.option = ParsePrefs(urlData, "target_milestone");

	// set Product Preferences value
	preferences.PRODUCT.option = ParsePrefs(urlData, "product");
	
	// set Component Preferences value
	preferences.COMPONENT.option = ParsePrefs(urlData, "component");
	
	// set Version Preferences value
	preferences.VERSION.option = ParsePrefs(urlData, "version");
	
	// clean up a smidge
	urlData = null;
}

function ParsePrefs(strUrlData, strPref)
{
	// parse the data out of the URL Data to populate Preferences Dropdowns
	var strFinalList = [];
	var intLoopy;
	
	// add a blank row to allow blank selection
	strFinalList[0] = "";
	
	// find the beginning of the product table
	var intIndex = String(strUrlData).indexOf("id=\"" + String(strPref) + "\"");
	var strElements = String(strUrlData).substring(intIndex);

	// find the end of the product table
	intIndex = strElements.indexOf("</select>");
	strElements = Left(strElements, intIndex);

	// use regex to find all options
	strOptions = [];
	strOptions = strElements.match(/<option value=\".*?\"/g);

    if (strOptions != undefined)
	{
		// loop through options
		strFinalList = [];
		strFinalList[0] = "";
		for (intLoopy = 0; intLoopy < strOptions.length; intLoopy++)
		{
			strOptions[intLoopy] = String(strOptions[intLoopy]).substring(15);
			strOptions[intLoopy] = Left(String(strOptions[intLoopy]), String(strOptions[intLoopy]).length - 1);
			strOptions[intLoopy] = UnEscapeToo(strOptions[intLoopy], 1);
			strFinalList[intLoopy + 1] = strOptions[intLoopy];
		}
	}

	// clean up
	strElements = [];
	strOptions = [];
	strUrlData = null;
	
	// return preferences value array
	return strFinalList;
}

function LoadBugs(urlFeed)
{
	// Show the Loading Bugs header
	ShowHeader("(Loading Bugs...)", "");

    // suppress GUI updates until all are completed
    suppressUpdates();

    // translate widths into starting positions
    var intStartCol = [];
	var strBugData = [];
    intStartCol[1] = 12;
    intStartCol[2] = 12 + intColWidthReal[1];
    intStartCol[3] = 12 + intColWidthReal[1] + intColWidthReal[2];
    intStartCol[4] = 12 + intColWidthReal[1] + intColWidthReal[2] + intColWidthReal[3];
    intStartCol[5] = 12 + intColWidthReal[1] + intColWidthReal[2] + intColWidthReal[3] + intColWidthReal[4];
    intStartCol[6] = 12 + intColWidthReal[1] + intColWidthReal[2] + intColWidthReal[3] + intColWidthReal[4] + intColWidthReal[5];

	// Remove CRs and LFs
	urlFeed = urlFeed.replace(/[\n|\r]/gi,"");
		
	// get the data block for each bug
	strBugData = urlFeed.match(/<td class=\"first-child\">.*?<\/tr>/gi);

    // Update the displayed bugs
    var intLastUsedRow = -1;

    // setup summary information holders
	var intStatus = [];
	var strStatusDisp = [];
	var intPriority = [];
	var strPriorityDisp = [];
	var intSeverity = [];
	var strSeverityDisp = [];
	
	var intClear;
	for (intClear = 0; intClear < 51; intClear++)
	{
    	intStatus[intClear] = 0;
        intPriority[intClear] = 0;
        intSeverity[intClear] = 0;
	}
	var intStartBug = 0;
	var intEndBug = 0;
    var intDisplayRow;
	var strCells;
	var lineArray;
	var tmpBugNumber; 
	var tmpAssignedTo;
	var tmpURL;
	var tmpPri;
	var strPriBGColor;
	var strPriColor;
	var tmpSev;
	var strSevBGColor;
	var strSevColor;
	var tmpStatus;
	var strStatusColor;
	var strStatusBGColor;
	var intRow;
	var j;
	var strAssignedToBGColor;
	var strAssignedToColor;
	
	intLastBug = -1;
	intDisplayRow = 0;
    if(strBugData != undefined)
    {
		intLastBug = strBugData.length - 1;
		
        // figure out which bug to start with
        if ((parseInt(intTopBug, 10) + parseInt(intBugsPerScreen, 10) - 1) > intLastBug)
        {
            intStartBug = intLastBug - intBugsPerScreen + 1;
            if (intStartBug < 0)
            {
            intStartBug = 0;
            }
        }
        else
        {
        intStartBug = intTopBug;
        }

        // figure out which bug to end with
        intEndBug = parseInt(intStartBug, 10) + parseInt(intBugsPerScreen, 10) - 1;
        if (intEndBug > intLastBug)
        {
        intEndBug = intLastBug;
        }

        // loop through all of the rows in the set
        intDisplayRow = 0;
    	for (intRow = 0; intRow <= intLastBug; intRow++)
        {
            // chop each line into field chunks
    		strCells = strBugData[intRow].match(/<td.*?>(.*?)<\/td>/gi);
    		lineArray = [];
    		for (j = 0; j < strCells.length; j++)
    	    {
                // remove HTML from each chunk
    			lineArray[j] = strCells[j].replace(/(<([^>]+)>)/ig,"");
    			// convert tabs to spaces
    			lineArray[j] = String(lineArray[j].replace(/[\t]/gi,""));
    			// convert double spaces to single spaces
    			lineArray[j] = String(lineArray[j].replace(/\s\s/gi," "));
    			// trim leading and trailing whitespace
    			lineArray[j] = Trim(lineArray[j]);
    	    }

            // bug number
    		tmpBugNumber = lineArray[0].replace(/[^0-9]/gi,"");

            // bug url
            tmpURL = strBaseUrl + "/show_bug.cgi?id=" + String(tmpBugNumber);

            // set bug priority cell values
			lineArray[2] = UnEscapeToo(lineArray[2], preferences.EXTENDEDTRANSLATE.value);
			SetBugColor(1, lineArray[2]);
			strPriBGColor = strCellBGColor;
			strPriColor = strCellColor;
            intPriority[parseInt(intCellReturn, 10)]++;
			strPriorityDisp[parseInt(intCellReturn, 10)] = lineArray[2];

            // set bug severity cell values
			lineArray[1] = UnEscapeToo(lineArray[1], preferences.EXTENDEDTRANSLATE.value);
			SetBugColor(0, lineArray[1]);
			strSevBGColor = strCellBGColor;
			strSevColor = strCellColor;
            intSeverity[parseInt(intCellReturn, 10)]++;
			strSeverityDisp[parseInt(intCellReturn, 10)] = lineArray[1];
			
            // set bug status cell values
			lineArray[5] = UnEscapeToo(lineArray[5], preferences.EXTENDEDTRANSLATE.value);
			SetBugColor(2, lineArray[5]);
			strStaBGColor = strCellBGColor;
			strStaColor = strCellColor;
            intStatus[parseInt(intCellReturn, 10)]++;
			strStatusDisp[parseInt(intCellReturn, 10)] = lineArray[5];
			tmpStatus = String(lineArray[5]).toUpperCase();
			
            // is current row between intStartBug and intEndBug
            if ((intRow >= intStartBug) && (intRow <= intEndBug))
            {
                // row has content
                intLastUsedRow = intDisplayRow;
				
				// HTML decode the description and assigned to name
        		lineArray[7] = UnEscapeToo(lineArray[7], 1);
        		lineArray[4] = UnEscapeToo(lineArray[4], 1);

	            // bug assigned to name
	    		tmpAssignedTo = lineArray[4];
				
				// if Assigned To = Login Name then highlight the bug
    			if (lineArray[4].toUpperCase() === strUser.toUpperCase())
    			{
    			    // set highlight on assigned to field
    				strAssignedToBGColor = strBugAssToMeBGColor;
    				strAssignedToColor = strBugAssToMeColor;
    			}
    			else
    			{
    			    // set normal color on assigned to field
    				strAssignedToBGColor = "#555555";
    				strAssignedToColor = "#ffffff";
    			}
				
    			// bug #
    			imageBar1[intDisplayRow].hOffset = intStartCol[1];
    			imageBar1[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar1[intDisplayRow].width = intColWidthReal[1];
    			imageBar1[intDisplayRow].height = 16;
    			imageBar1[intDisplayRow].opacity = 255;
    			imageBar1[intDisplayRow].src = "Resources/bar.png";
    			imageBar1[intDisplayRow].zOrder = 0;
    			imageBar1[intDisplayRow].href = tmpURL;
    			imageBar1[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar1[intDisplayRow].window = mainWindow;
                imageBar1[intDisplayRow].colorize = "#555555";
                imageBar1[intDisplayRow].visible = true;
    			textBar1[intDisplayRow].data = "    " + tmpBugNumber;
    			textBar1[intDisplayRow].hOffset = intStartCol[1] - 6;
    			textBar1[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar1[intDisplayRow].size = intMasterFontSize;
    			textBar1[intDisplayRow].opacity = 255;
    			textBar1[intDisplayRow].zOrder = 1;
    			textBar1[intDisplayRow].color = "#ffffff";
    			textBar1[intDisplayRow].truncation = "end";
                textBar1[intDisplayRow].width = intColWidthReal[1];
                textBar1[intDisplayRow].window = mainWindow;
                textBar1[intDisplayRow].visible = true;
                textBar1[intDisplayRow].style.fontFamily = strFontFamily;

    			// status
    			imageBar2[intDisplayRow].hOffset = intStartCol[2];
    			imageBar2[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar2[intDisplayRow].width = intColWidthReal[2];
    			imageBar2[intDisplayRow].height = 16;
    			imageBar2[intDisplayRow].opacity = 255;
    			imageBar2[intDisplayRow].src = "Resources/bar.png";
    			imageBar2[intDisplayRow].zOrder = 0;
    			imageBar2[intDisplayRow].href = tmpURL;
    			imageBar2[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar2[intDisplayRow].window = mainWindow;
    			imageBar2[intDisplayRow].colorize = strStaBGColor;
    			imageBar2[intDisplayRow].visible = true;
    			textBar2[intDisplayRow].data = "  " + tmpStatus;
    			textBar2[intDisplayRow].hOffset = intStartCol[2];
    			textBar2[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar2[intDisplayRow].size = intMasterFontSize;
    			textBar2[intDisplayRow].opacity = 255;
    			textBar2[intDisplayRow].zOrder = 1;
    			textBar2[intDisplayRow].color = strStaColor;
    			textBar2[intDisplayRow].truncation = "end";
                textBar2[intDisplayRow].width = intColWidthReal[2];
                textBar2[intDisplayRow].window = mainWindow;
                textBar2[intDisplayRow].visible = true;
                textBar2[intDisplayRow].style.fontFamily = strFontFamily;

    			// priority
    			imageBar3[intDisplayRow].hOffset = intStartCol[3];
    			imageBar3[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar3[intDisplayRow].width = intColWidthReal[3];
    			imageBar3[intDisplayRow].height = 16;
    			imageBar3[intDisplayRow].opacity = 255;
    			imageBar3[intDisplayRow].src = "Resources/bar.png";
    			imageBar3[intDisplayRow].zOrder = 0;
    			imageBar3[intDisplayRow].href = tmpURL;
    			imageBar3[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar3[intDisplayRow].window = mainWindow;
    			imageBar3[intDisplayRow].colorize = strPriBGColor;
    			imageBar3[intDisplayRow].visible = true;
    			textBar3[intDisplayRow].data = "  " + lineArray[2];
    			textBar3[intDisplayRow].hOffset = intStartCol[3];
    			textBar3[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar3[intDisplayRow].size = intMasterFontSize;
    			textBar3[intDisplayRow].opacity = 255;
    			textBar3[intDisplayRow].zOrder = 1;
    			textBar3[intDisplayRow].color = strPriColor;
    			textBar3[intDisplayRow].truncation = "end";
                textBar3[intDisplayRow].width = intColWidthReal[3];
                textBar3[intDisplayRow].window = mainWindow;
                textBar3[intDisplayRow].visible = true;
                textBar3[intDisplayRow].style.fontFamily = strFontFamily;

    			// severity
    			imageBar4[intDisplayRow].hOffset = intStartCol[4];
    			imageBar4[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar4[intDisplayRow].width = intColWidthReal[4];
    			imageBar4[intDisplayRow].height = 16;
    			imageBar4[intDisplayRow].opacity = 255;
    			imageBar4[intDisplayRow].src = "Resources/bar.png";
    			imageBar4[intDisplayRow].zOrder = 0;
    			imageBar4[intDisplayRow].href = tmpURL;
    			imageBar4[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar4[intDisplayRow].window = mainWindow;
    			imageBar4[intDisplayRow].colorize = strSevBGColor;
    			imageBar4[intDisplayRow].visible = true;
    			textBar4[intDisplayRow].data = "  " + lineArray[1];
    			textBar4[intDisplayRow].hOffset = intStartCol[4];
    			textBar4[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar4[intDisplayRow].size = intMasterFontSize;
    			textBar4[intDisplayRow].opacity = 255;
    			textBar4[intDisplayRow].zOrder = 1;
    			textBar4[intDisplayRow].color = strSevColor;
    			textBar4[intDisplayRow].truncation = "end";
                textBar4[intDisplayRow].width = intColWidthReal[4];
                textBar4[intDisplayRow].window = mainWindow;
                textBar4[intDisplayRow].visible = true;
                textBar4[intDisplayRow].style.fontFamily = strFontFamily;

    			// title
    			imageBar5[intDisplayRow].hOffset = intStartCol[5];
    			imageBar5[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar5[intDisplayRow].width = intColWidthReal[5];
    			imageBar5[intDisplayRow].height = 16;
    			imageBar5[intDisplayRow].opacity = 255;
    			imageBar5[intDisplayRow].src = "Resources/bar.png";
    			imageBar5[intDisplayRow].zOrder = 0;
    			imageBar5[intDisplayRow].href = tmpURL;
    			imageBar5[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar5[intDisplayRow].window = mainWindow;
    			imageBar5[intDisplayRow].colorize = "#333344";
    			imageBar5[intDisplayRow].visible = true;
    			textBar5[intDisplayRow].data = "  " + String(lineArray[7]);
    			textBar5[intDisplayRow].hOffset = intStartCol[5];
    			textBar5[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar5[intDisplayRow].size = intMasterFontSize;
    			textBar5[intDisplayRow].opacity = 255;
    			textBar5[intDisplayRow].zOrder = 1;
    			textBar5[intDisplayRow].color = "#ffffff";
    			textBar5[intDisplayRow].truncation = "end";
                textBar5[intDisplayRow].width = intColWidthReal[5];
                textBar5[intDisplayRow].window = mainWindow;
                textBar5[intDisplayRow].visible = true;
                textBar5[intDisplayRow].style.fontFamily = strFontFamily;
				
    			// assigned to
    			imageBar6[intDisplayRow].hOffset = intStartCol[6];
    			imageBar6[intDisplayRow].vOffset = 30 + (intDisplayRow * 16);
    			imageBar6[intDisplayRow].width = intColWidthReal[6];
    			imageBar6[intDisplayRow].height = 16;
    			imageBar6[intDisplayRow].opacity = 255;
    			imageBar6[intDisplayRow].src = "Resources/bar.png";
    			imageBar6[intDisplayRow].zOrder = 0;
    			imageBar6[intDisplayRow].href = tmpURL;
    			imageBar6[intDisplayRow].onMouseDown = openMyUrl;
    			imageBar6[intDisplayRow].window = mainWindow;
    			imageBar6[intDisplayRow].colorize = strAssignedToBGColor;
    			imageBar6[intDisplayRow].visible = true;
    			textBar6[intDisplayRow].data = "  " + tmpAssignedTo;
    			textBar6[intDisplayRow].hOffset = intStartCol[6];
    			textBar6[intDisplayRow].vOffset = 41 + (intDisplayRow * 16);
    			textBar6[intDisplayRow].size = intMasterFontSize;
    			textBar6[intDisplayRow].opacity = 255;
    			textBar6[intDisplayRow].zOrder = 1;
    			textBar6[intDisplayRow].color = strAssignedToColor;
    			textBar6[intDisplayRow].truncation = "end";
                textBar6[intDisplayRow].width = intColWidthReal[6];
                textBar6[intDisplayRow].window = mainWindow;
                textBar6[intDisplayRow].visible = true;
                textBar6[intDisplayRow].style.fontFamily = strFontFamily;
				}
    		else
    		{
    		    // row has no content - hide prior objects if they exist
                HideBar(intDisplayRow);
			}
			if (intRow >= intStartBug)
			{
 			// move to the next display row - after the first shown row is found
			intDisplayRow++;
			}
    	}
    }
    
	// hide any remaining rows before loading footer
    var intSwat;
	if (intDisplayRow < 50)
    {
		for (intSwat = intDisplayRow; intSwat < 50; intSwat++)
        {
            HideBar(intSwat);
        }
    }
	
    // load footer in 3 pieces (so right and left curves don't distort)
	imgFooterLeft.src = "Resources/banner_left_b.png";
	imgFooterLeft.colorize = "#333333";
	imgFooterLeft.opacity = 255;
	imgFooterLeft.zOrder = -1;
	imgFooterLeft.hOffset = 0;
	imgFooterLeft.vOffset = 30 + ((intLastUsedRow + 1) * 16);
	imgFooterLeft.width = 40;
	imgFooterLeft.height = 30;
	imgFooterLeft.onMouseDown = "";
	imgFooterLeft.window = mainWindow;
	
	imgFooterCenter.src = "Resources/banner_center_b.png";
	imgFooterCenter.colorize = "#333333";
	imgFooterCenter.opacity = 255;
	imgFooterCenter.zOrder = -1;
	imgFooterCenter.hOffset = 40;
	imgFooterCenter.vOffset = 30 + ((intLastUsedRow + 1) * 16);
	imgFooterCenter.width = intTotalWidth - 80;
	imgFooterCenter.height = 30;
	imgFooterCenter.onMouseDown = "";
	imgFooterCenter.window = mainWindow;

	imgFooterRight.src = "Resources/banner_right_b.png";
	imgFooterRight.colorize = "#333333";
	imgFooterRight.opacity = 255;
	imgFooterRight.zOrder = -1;
	imgFooterRight.hOffset = intTotalWidth - 40;
	imgFooterRight.vOffset = 30 + ((intLastUsedRow + 1) * 16);
	imgFooterRight.width = 40;
	imgFooterRight.height = 30;
	imgFooterRight.onMouseDown = "";
	imgFooterRight.window = mainWindow;

	imgFooterScrollUp.src = "Resources/arrow_up.png";
	imgFooterScrollUp.colorize = "#666666";
	imgFooterScrollUp.opacity = 255;
	imgFooterScrollUp.zOrder = 0;
	imgFooterScrollUp.hOffset = intTotalWidth - 41;
	imgFooterScrollUp.vOffset = 34 + ((intLastUsedRow + 1) * 16);
	imgFooterScrollUp.width = 10;
	imgFooterScrollUp.height = 10;
	imgFooterScrollUp.onMouseDown = "";
	imgFooterScrollUp.tracking="rectangle";
	imgFooterScrollUp.window = mainWindow;

	imgFooterScrollDown.src = "Resources/arrow_down.png";
	imgFooterScrollDown.colorize = "#666666";
	imgFooterScrollDown.opacity = 255;
	imgFooterScrollDown.zOrder = 0;
	imgFooterScrollDown.hOffset = intTotalWidth - 28;
	imgFooterScrollDown.vOffset = 34 + ((intLastUsedRow + 1) * 16);
	imgFooterScrollDown.width = 10;
	imgFooterScrollDown.height = 10;
	imgFooterScrollDown.onMouseDown = "";
	imgFooterScrollDown.tracking="rectangle";
	imgFooterScrollDown.window = mainWindow;

	imgFooterNewBug.src = "Resources/asterisk_yellow.png";
	imgFooterNewBug.opacity = 255;
	imgFooterNewBug.zOrder = 0;
	imgFooterNewBug.hOffset = 17;
	imgFooterNewBug.vOffset = 34 + ((intLastUsedRow + 1) * 16);
	imgFooterNewBug.width = 10;
	imgFooterNewBug.height = 10;
	imgFooterNewBug.window = mainWindow;
	imgFooterNewBug.tooltip = "Enter New Bug";
	imgFooterNewBug.tracking="rectangle";
	imgFooterNewBug.href = strBaseUrl + "/enter_bug.cgi";
	imgFooterNewBug.onMouseDown = openMyUrl;

    // enable/disable the arrows as appropriate
    if (intStartBug > 0)
    {
    	imgFooterScrollUp.colorize = "#ffff00";
    	imgFooterScrollUp.onMouseDown = ScrollUp;
    	imgFooterScrollUp.tooltip = "Scroll Up";
    }
    else
    {
    	imgFooterScrollUp.colorize = "#666666";
    	imgFooterScrollUp.onMouseDown = "";
    	imgFooterScrollUp.tooltip = "";
    }
    if ((intLastBug !== -1) && (intEndBug < intLastBug))
    {
    	imgFooterScrollDown.colorize = "#ffff00";
    	imgFooterScrollDown.onMouseDown = ScrollDown;
    	imgFooterScrollDown.tooltip = "Scroll Down";
    }
    else
    {
    	imgFooterScrollDown.colorize = "#666666";
    	imgFooterScrollDown.onMouseDown = "";
    	imgFooterScrollDown.tooltip = "";
    }

    // Set the footer information
	var intDisplayLoop;
	var intShownOne;
	var strFooter;
    strFooter = "";
    if ((intLastBug !== -1) && (parseInt(intFooterStatus, 10) === 1))
    {
        // add bug status summary
        if (strFooter.length > 0)
        {
            strFooter = strFooter + "   ";
        }
        intShownOne = 0;
        strFooter = strFooter + "Status- ";
		for (intDisplayLoop = 0; intDisplayLoop < 51; intDisplayLoop++)
		{
			if (parseInt(intStatus[intDisplayLoop], 10) > 0)
			{
	            if (intShownOne === 1)
	            {
	                strFooter = strFooter + ", ";
	            }
	            strFooter = strFooter + strStatusDisp[intDisplayLoop] + ":" + String(intStatus[intDisplayLoop]);
	            intShownOne = 1;
			}
		}
	}

    if ((intLastBug !== -1) && (parseInt(intFooterPriority, 10) === 1))
    {
        // add bug priority summary
        if (strFooter.length > 0)
        {
            strFooter = strFooter + "   ";
        }
        intShownOne = 0;
        strFooter = strFooter + "Pri- ";
		for (intDisplayLoop = 0; intDisplayLoop < 51; intDisplayLoop++)
		{
			if (parseInt(intPriority[intDisplayLoop], 10) > 0)
			{
	            if (intShownOne === 1)
	            {
	                strFooter = strFooter + ", ";
	            }
	            strFooter = strFooter + strPriorityDisp[intDisplayLoop] + ":" + String(intPriority[intDisplayLoop]);
	            intShownOne = 1;
			}
		}
	}

    if ((intLastBug !== -1) && (parseInt(intFooterSeverity, 10) === 1))
    {
        // add bug severity summary
        if (strFooter.length > 0)
        {
            strFooter = strFooter + "   ";
        }
        intShownOne = 0;
        strFooter = strFooter + "Sev- ";
		for (intDisplayLoop = 0; intDisplayLoop < 51; intDisplayLoop++)
		{
			if (parseInt(intSeverity[intDisplayLoop], 10) > 0)
			{
	            if (intShownOne === 1)
	            {
	                strFooter = strFooter + ", ";
	            }
	            strFooter = strFooter + strSeverityDisp[intDisplayLoop] + ":" + String(intSeverity[intDisplayLoop]);
	            intShownOne = 1;
			}
		}
    }

    // add Sorted By Information
	var strSortedBy = "";
    if (intLastBug !== -1)
    {
        if (strFooter.length > 0)
        {
            strFooter = strFooter + "   ";
        }
		
		// build the sorted by string
		if (strSortedByPri.length > 0)
		{
			strSortedBy = strSortedByPri;
			if (String(intSortedByPriDesc) == "1")
			{
				strSortedBy = strSortedBy + " desc";
			}
		}
		if (strSortedBySec.length > 0)
		{
			if (strSortedBy.length > 0)
			{
				strSortedBy = strSortedBy + ", ";
			}
			strSortedBy = strSortedBy + strSortedBySec;
			if (String(intSortedBySecDesc) == "1")
			{
				strSortedBy = strSortedBy + " desc";
			}
		}
		if (strSortedByTer.length > 0)
		{
			if (strSortedBy.length > 0)
			{
				strSortedBy = strSortedBy + ", ";
			}
			strSortedBy = strSortedBy + strSortedByTer;
			if (String(intSortedByTerDesc) == "1")
			{
				strSortedBy = strSortedBy + " desc";
			}
		}
		
		// clean it up for display
		strSortedBy = strSortedBy.replace(/bug_id/, "Bug #");
		strSortedBy = strSortedBy.replace(/bug_status/, "Status");
		strSortedBy = strSortedBy.replace(/priority/, "Priority");
		strSortedBy = strSortedBy.replace(/bug_severity/, "Severity");
		strSortedBy = strSortedBy.replace(/map_assigned_to.login_name/, "Assigned To");

		// add to the footer
        strFooter = strFooter + "(Sorted By:";
        strFooter = strFooter + strSortedBy + ")";

		// add assigned only to me info
        if (parseInt(intAssignedToMe, 10) === 1)
        {
            strFooter = strFooter + "   (Assigned To:" + strUser + ")";
        }
    }

    // now set the text
	strFooterText.hOffset = 32;
	strFooterText.vOffset = 42 + ((intLastUsedRow + 1) * 16);
	strFooterText.size = intMasterFontSize - 1;
	strFooterText.opacity = 255;
	strFooterText.zOrder = 5;
	strFooterText.color = "#ffffff";
	strFooterText.data = strFooter;
	strFooterText.window = mainWindow;
	strFooterText.truncation = "end";
    strFooterText.width = intTotalWidth - 74;
    strFooterText.style.fontFamily = strFontFamily;

	// clean up old variables
	intStatus = [];
	intPriority = [];
	intSeverity = [];
	lineArray = [];
	intStartCol = [];
	strBugData = [];
	urlFeed = "";
	intCellReturn = null;
	strCellDisplay = "";
	strCellBGColor = "";
	strCellColor = "";
	
	// Resize the main window width to accomodate the displayed control
	mainWindow.height = 50 + ((intLastUsedRow + 1) * 16);
	
	// Update the application shadow
	mainWindow.recalcShadow();

	// Show the header
	ShowHeader(strAddDisplay, strFullUrl);

    // resume GUI updates
    resumeUpdates();
	updateNow();
	
	// return the number of bugs
	return(intLastBug + 1);
}

function SetBugColor(strMode, strValue)
{
	var intLoopy;
	var intLimit;
	var strCheckValue;
	var strChoppedValue;
	
	// set defaults for each mode
	switch(strMode)
	{
		case 0:
			strCellBGColor = strDefaultBugSevTextBGColor;
			strCellColor = strDefaultBugSevTextColor;
			intCellReturn = "10";
			intLimit = strBugSevText.length;
			break;
		case 1:
			strCellBGColor = strDefaultBugPriTextBGColor;
			strCellColor = strDefaultBugPriTextColor;
			intCellReturn = "10";
			intLimit = strBugPriText.length;
			break;
		case 2:
			strCellBGColor = strDefaultBugStaTextBGColor;
			strCellColor = strDefaultBugStaTextColor;
			intCellReturn = "10";
			intLimit = strBugStaText.length;
			break;
	}

	// find a matching value
	for (intLoopy = 0; intLoopy < intLimit; intLoopy++)
	{
		switch(strMode)
		{
			case 0:
				strCheckValue = strBugSevText[intLoopy];
				break;
			case 1:
				strCheckValue = strBugPriText[intLoopy];
				break;
			case 2:
				strCheckValue = strBugStaText[intLoopy];
				break;
		}
		if (strValue.length >= strCheckValue.length)
		{
			strChoppedValue = String(Left(strValue, strCheckValue.length)).toUpperCase();
			if (strChoppedValue == strCheckValue)
			{
				// we have a match - set the colors!
				switch(strMode)
				{
					case 0:
						strCellBGColor = strBugSevBG[intLoopy];
						strCellColor = strBugSevColor[intLoopy];
						break;
					case 1:
						strCellBGColor = strBugPriBG[intLoopy];
						strCellColor = strBugPriColor[intLoopy];
						break;
					case 2:
						strCellBGColor = strBugStaBG[intLoopy];
						strCellColor = strBugStaColor[intLoopy];
						break;
				}
				intCellReturn = intLoopy;
				break;
			}
		}
	}
}

function ScrollUp()
{
    // determine the new top bug and redisplay the list
    intTopBug = intTopBug - parseInt(intBugsPerScreen, 10);
    if (intTopBug < 0)
    {
        intTopBug = 0;
    }
    LoadBugs(urlInput);
}

function ScrollDown()
{
    // determine the new top bug and redisplay the list
    intTopBug = intTopBug + parseInt(intBugsPerScreen, 10);
    if (intTopBug > intLastBug)
    {
        intTopBug = intLastBug - intBugsPerScreen;
    }
    if (intTopBug < 0)
    {
        intTopBug = 0;
    }
    LoadBugs(urlInput);
}

function ShowHeader(strAddText, strUrlRef)
{
    // load image in 3 pieces (so right and left curves don't distort)
	imgHeaderLeft.src = "Resources/banner_left.png";
	imgHeaderLeft.colorize = "#333333";
	imgHeaderLeft.opacity = 255;
	imgHeaderLeft.zOrder = -1;
	imgHeaderLeft.hOffset = 0;
	imgHeaderLeft.vOffset = 0;
	imgHeaderLeft.width = 40;
	imgHeaderLeft.height = 30;
	imgHeaderLeft.window = mainWindow;

	imgHeaderCenter.src = "Resources/banner_center.png";
	imgHeaderCenter.colorize = "#333333";
	imgHeaderCenter.opacity = 255;
	imgHeaderCenter.zOrder = -1;
	imgHeaderCenter.hOffset = 40;
	imgHeaderCenter.vOffset = 0;
	imgHeaderCenter.width = intTotalWidth - 80;
	imgHeaderCenter.height = 30;
	imgHeaderCenter.window = mainWindow;

	imgHeaderRight.src = "Resources/banner_right.png";
	imgHeaderRight.colorize = "#333333";
	imgHeaderRight.opacity = 255;
	imgHeaderRight.zOrder = -1;
	imgHeaderRight.hOffset = intTotalWidth - 40;
	imgHeaderRight.vOffset = 0;
	imgHeaderRight.width = 40;
	imgHeaderRight.height = 30;
	imgHeaderRight.window = mainWindow;

	imgHeaderRefresh.src = "Resources/arrow_refresh_small.png";
	imgHeaderRefresh.opacity = 255;
	imgHeaderRefresh.zOrder = 10;
	imgHeaderRefresh.hOffset = intTotalWidth - 51;
	imgHeaderRefresh.vOffset = 13;
	imgHeaderRefresh.width = 13;
	imgHeaderRefresh.height = 13;
	imgHeaderRefresh.onMouseDown = BugMon;
	imgHeaderRefresh.tracking="rectangle";
	imgHeaderRefresh.window = mainWindow;
	
	imgHeaderColor.src = "Resources/palette.png";
	imgHeaderColor.opacity = 255;
	imgHeaderColor.zOrder = 10;
	imgHeaderColor.hOffset = intTotalWidth - 38;
	imgHeaderColor.vOffset = 14;
	imgHeaderColor.width = 11;
	imgHeaderColor.height = 11;
	imgHeaderColor.onMouseDown = ConfigColors;
	imgHeaderColor.tracking="rectangle";
	imgHeaderColor.window = mainWindow;
	
	imgHeaderHelp.src = "Resources/help.png";
	imgHeaderHelp.opacity = 255;
	imgHeaderHelp.zOrder = 10;
	imgHeaderHelp.hOffset = intTotalWidth - 25;
	imgHeaderHelp.vOffset = 14;
	imgHeaderHelp.width = 11;
	imgHeaderHelp.height = 11;
	imgHeaderHelp.href = resolvePath("./Resources/help.html");
	imgHeaderHelp.onMouseDown = openMyUrl;
	imgHeaderHelp.tracking="rectangle";
	imgHeaderHelp.window = mainWindow;

	strHeaderTitleText.hOffset = 18;
	strHeaderTitleText.vOffset = 23;
	strHeaderTitleText.size = intMasterFontSize + 1;
	strHeaderTitleText.opacity = 255;
	strHeaderTitleText.zOrder = 5;
	strHeaderTitleText.color = "#ffffff";
	strHeaderTitleText.data =  "BugMon -";
	strHeaderTitleText.window = mainWindow;
	strHeaderTitleText.truncation = "end";
    strHeaderTitleText.width = intTotalWidth - 170 - ((intMasterFontSize - 8) * 11);
    strHeaderTitleText.style.fontFamily = strFontFamily;
	
	strHeaderText.hOffset = 75;
	strHeaderText.vOffset = 23;
	strHeaderText.size = intMasterFontSize + 1;
	strHeaderText.opacity = 255;
	strHeaderText.zOrder = 5;
	strHeaderText.color = "#ffffff";
	strHeaderText.data = strAddText;
	strHeaderText.window = mainWindow;
	strHeaderText.truncation = "end";
    strHeaderText.style.fontFamily = strFontFamily;

	var intMaxTextWidth = intTotalWidth - 220 - ((intMasterFontSize - 8) * 11)
	// set to -1 to default width to current width of text in field
	strHeaderText.width = -1;
	if (strHeaderText.width > intMaxTextWidth)
	{
		strHeaderText.width = intMaxTextWidth;
	}
	
	if (strUrlRef.length > 7)
	{
		strHeaderText.href = strUrlRef;
		strHeaderText.onMouseDown = openMyUrl;
	}
	else
	{
		strHeaderText.onMouseDown = "";
	}
	
	strTime.vOffset = 23;
	strTime.size = intMasterFontSize - 1;
	strTime.opacity = 255;
	strTime.zOrder = 5;
	strTime.color = "#ffffff";
	strTime.data = String(Date()).substr(0,25);
	strTime.window = mainWindow;
	strTime.hOffset = intTotalWidth - 142 - ((intMasterFontSize - 8) * 11);
    strTime.style.fontFamily = strFontFamily;

    // force a GUI update
    updateNow();
}

function LoadColors()
{
	// load bug color arrays from Preferences
	var strTempText = [];
	var strTempColor = [];
	var strTempBGColor = [];

	// load default colors
	strDefaultBugSevTextColor = preferences.VCDEFAULT.value;	
	strDefaultBugSevTextBGColor = preferences.VBDEFAULT.value;
	strDefaultBugPriTextColor = preferences.PCDEFAULT.value; 		
	strDefaultBugPriTextBGColor = preferences.PBDEFAULT.value;
	strDefaultBugStaTextColor = preferences.SCDEFAULT.value; 		
	strDefaultBugStaTextBGColor = preferences.SBDEFAULT.value;
	
	// Load Severity
	strTempText = Array(preferences.VT0.value,preferences.VT1.value,preferences.VT2.value,preferences.VT3.value,preferences.VT4.value,preferences.VT5.value,preferences.VT6.value,preferences.VT7.value,preferences.VT8.value,preferences.VT9.value);
	strTempColor = Array(preferences.VC0.value,preferences.VC1.value,preferences.VC2.value,preferences.VC3.value,preferences.VC4.value,preferences.VC5.value,preferences.VC6.value,preferences.VC7.value,preferences.VC8.value,preferences.VC9.value);
	strTempBGColor = Array(preferences.VB0.value,preferences.VB1.value,preferences.VB2.value,preferences.VB3.value,preferences.VB4.value,preferences.VB5.value,preferences.VB6.value,preferences.VB7.value,preferences.VB8.value,preferences.VB9.value);
	strBugSevText = [];
	strBugSevColor = [];
	strBugSevBG = [];
	BuildColorArray(0, strTempText, strTempColor, strTempBGColor);
	if (strBugSevText.length == 0)
	{
		// set a default value in case all were set blank
		strBugSevText[0] = "XXXXX";
		strBugSevColor[0] = preferences.VCDEFAULT.value;
		strBugSevBG[0] = preferences.VBDEFAULT.value;
	}
	
	// Load Priority
	strTempText = [];
	strTempColor = [];
	strTempBGColor = [];
	strTempText = Array(preferences.PT0.value,preferences.PT1.value,preferences.PT2.value,preferences.PT3.value,preferences.PT4.value,preferences.PT5.value,preferences.PT6.value,preferences.PT7.value,preferences.PT8.value,preferences.PT9.value);
	strTempColor = Array(preferences.PC0.value,preferences.PC1.value,preferences.PC2.value,preferences.PC3.value,preferences.PC4.value,preferences.PC5.value,preferences.PC6.value,preferences.PC7.value,preferences.PC8.value,preferences.PC9.value);
	strTempBGColor = Array(preferences.PB0.value,preferences.PB1.value,preferences.PB2.value,preferences.PB3.value,preferences.PB4.value,preferences.PB5.value,preferences.PB6.value,preferences.PB7.value,preferences.PB8.value,preferences.PB9.value);
	strBugPriText = [];
	strBugPriColor = [];
	strBugPriBG = [];
	BuildColorArray(1, strTempText, strTempColor, strTempBGColor);
	if (strBugPriText.length == 0)
	{
		// set a default value in case all were set blank
		strBugPriText[0] = "XXXXX";
		strBugPriColor[0] = preferences.PCDEFAULT.value;
		strBugPriBG[0] = preferences.PBDEFAULT.value;
	}
	
	// Load Status
	strTempText = [];
	strTempColor = [];
	strTempBGColor = [];
	strTempText = Array(preferences.ST0.value,preferences.ST1.value,preferences.ST2.value,preferences.ST3.value,preferences.ST4.value,preferences.ST5.value,preferences.ST6.value,preferences.ST7.value,preferences.ST8.value,preferences.ST9.value);
	strTempColor = Array(preferences.SC0.value,preferences.SC1.value,preferences.SC2.value,preferences.SC3.value,preferences.SC4.value,preferences.SC5.value,preferences.SC6.value,preferences.SC7.value,preferences.SC8.value,preferences.SC9.value);
	strTempBGColor = Array(preferences.SB0.value,preferences.SB1.value,preferences.SB2.value,preferences.SB3.value,preferences.SB4.value,preferences.SB5.value,preferences.SB6.value,preferences.SB7.value,preferences.SB8.value,preferences.SB9.value);
	strBugStaText = [];
	strBugStaColor = [];
	strBugStaBG = [];
	BuildColorArray(2, strTempText, strTempColor, strTempBGColor);
	if (strBugStaText.length == 0)
	{
		// set a default value in case all were set blank
		strBugStaText[0] = "XXXXX";
		strBugStaColor[0] = preferences.SCDEFAULT.value;
		strBugStaBG[0] = preferences.SBDEFAULT.value;
	}

	// clean up old arrays
	strTempText = [];
	strTempColor = [];
	strTempBGColor = [];

	// Set Colors for Bugs Assigned to Me
	strBugAssToMeColor = preferences.ASSTOMECOLOR.value;
	strBugAssToMeBGColor = preferences.ASSTOMEBGCOLOR.value;
}

function BuildColorArray(strMode, strTempText, strTempColor, strTempBGColor)
{
	// process temp arrays to build color arrays for Severity, Priority, and Status values
	// strMode = 2 - Status, 1 - Priority, 0 - Severity
	var strNewColor;
	var strNewBGColor;
	var intLoopy;
	var intLoopy2;
	var strTempTemp = [];
	var strDefaultBugTextColor;
	var strDefaultBugTextBGColor;
	var intNewValue = -1;
	
	// set default colors
	switch (strMode)
	{
		case 2:
			strDefaultBugTextColor = strDefaultBugStaTextColor;
			strDefaultBugTextBGColor = strDefaultBugStaTextBGColor;
			break;
		case 1:
			strDefaultBugTextColor = strDefaultBugPriTextColor;
			strDefaultBugTextBGColor = strDefaultBugPriTextBGColor;
			break;
		case 0:
			strDefaultBugTextColor = strDefaultBugSevTextColor;
			strDefaultBugTextBGColor = strDefaultBugSevTextBGColor;
			break;
	}

	// scrub the arrays to remove items with empty names and assign default colors to unspecified items
	for (intLoopy = 0; intLoopy < strTempText.length; intLoopy++)
	{
		if (String(strTempText[intLoopy]).length > 0)
		{
			// text is not empty - split on commas
			strTempTemp = [];
			strTempTemp = String(strTempText[intLoopy]).split(",");
			
			//  for each split item
			for (intLoopy2 = 0; intLoopy2 < strTempTemp.length; intLoopy2++)
			{
				// remove leading and trailing spaces
				strTempTemp[intLoopy2] = Trim(strTempTemp[intLoopy2]);
				
				// truncate to 4 characters if longer
				if (strTempTemp[intLoopy2].length > 4)
				{
					strTempTemp[intLoopy2] = Left(strTempTemp[intLoopy2], 4);
				}
				// now set the associated colors or defaults
				if (Trim(String(strTempColor[intLoopy])).length = 7)
				{
					strNewColor = String(strTempColor[intLoopy]);
				}
				else
				{
					strNewColor = strDefaultBugTextColor;
				}
				if (Trim(String(strTempBGColor[intLoopy])).length = 7)
				{
					strNewBGColor = String(strTempBGColor[intLoopy]);
				}
				else
				{
					strNewBGColor = strDefaultBugTextBGColor;
				}
				// save the color values
				intNewValue++;
				switch (strMode)
				{
					case 0:
						strBugSevText[intNewValue] = strTempTemp[intLoopy2];
						strBugSevColor[intNewValue] = strNewColor.toLowerCase();
						strBugSevBG[intNewValue] = strNewBGColor.toLowerCase();
						break;
					case 1:
						strBugPriText[intNewValue] = strTempTemp[intLoopy2];
						strBugPriColor[intNewValue] = strNewColor.toLowerCase();
						strBugPriBG[intNewValue] = strNewBGColor.toLowerCase();
						break;
					case 2:
						strBugStaText[intNewValue] = strTempTemp[intLoopy2];
						strBugStaColor[intNewValue] = strNewColor.toLowerCase();
						strBugStaBG[intNewValue] = strNewBGColor.toLowerCase();
						break;
				}
			}
		}
	}
	
	// clean up
	strTempTemp = [];
}

function ConfigColors()
{
	// stop the update timer
	tmrRefresh.ticking = "false";

    // suppress GUI updates until all are completed
    suppressUpdates();

	// format the color config screen
    // load header image in 3 pieces (so right and left curves don't distort)
	imgCHeaderLeft.src = "Resources/banner_left.png";
	imgCHeaderLeft.colorize = "#333333";
	imgCHeaderLeft.opacity = 255;
	imgCHeaderLeft.zOrder = -1;
	imgCHeaderLeft.hOffset = 0;
	imgCHeaderLeft.vOffset = 0;
	imgCHeaderLeft.width = 40;
	imgCHeaderLeft.height = 30;
	imgCHeaderLeft.window = colorWindow;

	imgCHeaderCenter.src = "Resources/banner_center.png";
	imgCHeaderCenter.colorize = "#333333";
	imgCHeaderCenter.opacity = 255;
	imgCHeaderCenter.zOrder = -1;
	imgCHeaderCenter.hOffset = 40;
	imgCHeaderCenter.vOffset = 0;
	imgCHeaderCenter.width = 420;
	imgCHeaderCenter.height = 30;
	imgCHeaderCenter.window = colorWindow;

	imgCHeaderRight.src = "Resources/banner_right.png";
	imgCHeaderRight.colorize = "#333333";
	imgCHeaderRight.opacity = 255;
	imgCHeaderRight.zOrder = -1;
	imgCHeaderRight.hOffset = 460;
	imgCHeaderRight.vOffset = 0;
	imgCHeaderRight.width = 40;
	imgCHeaderRight.height = 30;
	imgCHeaderRight.window = colorWindow;
	
	// load body background
	imgCBody.src = "Resources/bar2.png";
	imgCBody.colorize = "#333333";
	imgCBody.opacity = 255;
	imgCBody.zOrder = -1;
	imgCBody.hOffset = 12;
	imgCBody.vOffset = 30;
	imgCBody.width = 476;
	imgCBody.height = 400;
	imgCBody.window = colorWindow;

    // load footer image in 3 pieces (so right and left curves don't distort)
	imgCFooterLeft.src = "Resources/banner_left_b.png";
	imgCFooterLeft.colorize = "#333333";
	imgCFooterLeft.opacity = 255;
	imgCFooterLeft.zOrder = -1;
	imgCFooterLeft.hOffset = 0;
	imgCFooterLeft.vOffset = 430;
	imgCFooterLeft.width = 40;
	imgCFooterLeft.height = 30;
	imgCFooterLeft.window = colorWindow;

	imgCFooterCenter.src = "Resources/banner_center_b.png";
	imgCFooterCenter.colorize = "#333333";
	imgCFooterCenter.opacity = 255;
	imgCFooterCenter.zOrder = -1;
	imgCFooterCenter.hOffset = 40;
	imgCFooterCenter.vOffset = 430;
	imgCFooterCenter.width = 420;
	imgCFooterCenter.height = 30;
	imgCFooterCenter.window = colorWindow;

	imgCFooterRight.src = "Resources/banner_right_b.png";
	imgCFooterRight.colorize = "#333333";
	imgCFooterRight.opacity = 255;
	imgCFooterRight.zOrder = -1;
	imgCFooterRight.hOffset = 460;
	imgCFooterRight.vOffset = 430;
	imgCFooterRight.width = 40;
	imgCFooterRight.height = 30;
	imgCFooterRight.window = colorWindow;
	
	// title bar text
	txtCTitleBar.hOffset = 20;
	txtCTitleBar.vOffset = 23;
    txtCTitleBar.width = 200;
	txtCTitleBar.size = 11;
	txtCTitleBar.opacity = 255;
	txtCTitleBar.zOrder = 5;
	txtCTitleBar.color = "#ffffff";
	txtCTitleBar.data =  "Define Custom Bug Colors";
	txtCTitleBar.window = colorWindow;
	txtCTitleBar.truncation = "end";
    txtCTitleBar.style.fontFamily = strFontFamily;

	var intMasterWidth = 500;
	var intCellWidth = parseInt((intMasterWidth - 60) / 3);
	
	// column headers
	txtCStaHead.hOffset = 20;
	txtCStaHead.vOffset = 47;
    txtCStaHead.width = intCellWidth - 10;
	txtCStaHead.size = 10;
	txtCStaHead.opacity = 255;
	txtCStaHead.zOrder = 5;
	txtCStaHead.color = "#ffffff";
	txtCStaHead.data =  "Status Values";
	txtCStaHead.window = colorWindow;
	txtCStaHead.truncation = "end";
    txtCStaHead.style.fontFamily = strFontFamily;

	txtCPriHead.hOffset = 30 + intCellWidth;
	txtCPriHead.vOffset = 47;
    txtCPriHead.width = intCellWidth - 10;
	txtCPriHead.size = 10;
	txtCPriHead.opacity = 255;
	txtCPriHead.zOrder = 5;
	txtCPriHead.color = "#ffffff";
	txtCPriHead.data =  "Priority Values";
	txtCPriHead.window = colorWindow;
	txtCPriHead.truncation = "end";
    txtCPriHead.style.fontFamily = strFontFamily;

	txtCSevHead.hOffset = 40 + (2 * intCellWidth);
	txtCSevHead.vOffset = 47;
    txtCSevHead.width = intCellWidth - 10;
	txtCSevHead.size = 10;
	txtCSevHead.opacity = 255;
	txtCSevHead.zOrder = 5;
	txtCSevHead.color = "#ffffff";
	txtCSevHead.data =  "Severity Values";
	txtCSevHead.window = colorWindow;
	txtCSevHead.truncation = "end";
    txtCSevHead.style.fontFamily = strFontFamily;

	// load the text strings from prefs
	var strTempPriText = [];
	var strTempPriColor = [];
	var strTempPriBGColor = [];
	strTempPriText = Array(preferences.PT0.value,preferences.PT1.value,preferences.PT2.value,preferences.PT3.value,preferences.PT4.value,preferences.PT5.value,preferences.PT6.value,preferences.PT7.value,preferences.PT8.value,preferences.PT9.value,"");
	strTempPriColor = Array(preferences.PC0.value,preferences.PC1.value,preferences.PC2.value,preferences.PC3.value,preferences.PC4.value,preferences.PC5.value,preferences.PC6.value,preferences.PC7.value,preferences.PC8.value,preferences.PC9.value,"");
	strTempPriBGColor = Array(preferences.PB0.value,preferences.PB1.value,preferences.PB2.value,preferences.PB3.value,preferences.PB4.value,preferences.PB5.value,preferences.PB6.value,preferences.PB7.value,preferences.PB8.value,preferences.PB9.value,"");
	var strTempSevPriText = [];
	var strTempSevColor = [];
	var strTempSevBGColor = [];
	strTempSevText = Array(preferences.VT0.value,preferences.VT1.value,preferences.VT2.value,preferences.VT3.value,preferences.VT4.value,preferences.VT5.value,preferences.VT6.value,preferences.VT7.value,preferences.VT8.value,preferences.VT9.value,"");
	strTempSevColor = Array(preferences.VC0.value,preferences.VC1.value,preferences.VC2.value,preferences.VC3.value,preferences.VC4.value,preferences.VC5.value,preferences.VC6.value,preferences.VC7.value,preferences.VC8.value,preferences.VC9.value,"");
	strTempSevBGColor = Array(preferences.VB0.value,preferences.VB1.value,preferences.VB2.value,preferences.VB3.value,preferences.VB4.value,preferences.VB5.value,preferences.VB6.value,preferences.VB7.value,preferences.VB8.value,preferences.VB9.value,"");
	var strTempStaText = [];
	var strTempStaPriColor = [];
	var strTempStaBGColor = [];
	strTempStaText = Array(preferences.ST0.value,preferences.ST1.value,preferences.ST2.value,preferences.ST3.value,preferences.ST4.value,preferences.ST5.value,preferences.ST6.value,preferences.ST7.value,preferences.ST8.value,preferences.ST9.value,"");
	strTempStaColor = Array(preferences.SC0.value,preferences.SC1.value,preferences.SC2.value,preferences.SC3.value,preferences.SC4.value,preferences.SC5.value,preferences.SC6.value,preferences.SC7.value,preferences.SC8.value,preferences.SC9.value,"");
	strTempStaBGColor = Array(preferences.SB0.value,preferences.SB1.value,preferences.SB2.value,preferences.SB3.value,preferences.SB4.value,preferences.SB5.value,preferences.SB6.value,preferences.SB7.value,preferences.SB8.value,preferences.SB9.value,"");
	
	// now build and populate the values
	var intBaseVert = txtCStaHead.vOffset + 8;
	var intCreate = 0;
	for (intCreate = 0; intCreate < 11; intCreate++)
	{
		// status
		imgCSta[intCreate].src = "Resources/bar.png";
		imgCSta[intCreate].colorize = strTempStaBGColor[intCreate];
		imgCSta[intCreate].opacity = 255;
		imgCSta[intCreate].zOrder = 2;
		imgCSta[intCreate].hOffset = 20;
		imgCSta[intCreate].vOffset = intBaseVert + (intCreate * 22);
		imgCSta[intCreate].width = intCellWidth;
		imgCSta[intCreate].height = 18;
		imgCSta[intCreate].window = colorWindow;
		imgCSta[intCreate].cellID = String(intCreate);
		imgCSta[intCreate].onMouseDown = SetHiLightSta;
		
		txtCSta[intCreate].hOffset = 25;
		txtCSta[intCreate].vOffset = intBaseVert + (intCreate * 22) + 12;
	    txtCSta[intCreate].width = intCellWidth - 10;
		txtCSta[intCreate].size = 10;
		txtCSta[intCreate].opacity = 255;
		txtCSta[intCreate].zOrder = 5;
		txtCSta[intCreate].color = strTempStaColor[intCreate];
		txtCSta[intCreate].window = colorWindow;
		txtCSta[intCreate].truncation = "end";
		txtCSta[intCreate].data = strTempStaText[intCreate];
	    txtCSta[intCreate].style.fontFamily = strFontFamily;
		if (intCreate == 10)
		{
			txtCSta[intCreate].data =  "{Unknown Value}";
			txtCSta[intCreate].color = strDefaultBugStaTextColor;
			imgCSta[intCreate].colorize = strDefaultBugStaTextBGColor;
		}
		if ((intCreate > 6) && (intCreate < 10))
		{
			txtCSta[intCreate].visible = "0";
			imgCSta[intCreate].visible = "0";
		}
		
		// priority
		imgCPri[intCreate].src = "Resources/bar.png";
		imgCPri[intCreate].colorize = strTempPriBGColor[intCreate];
		imgCPri[intCreate].opacity = 255;
		imgCPri[intCreate].zOrder = 2;
		imgCPri[intCreate].hOffset = 30 + intCellWidth;
		imgCPri[intCreate].vOffset = intBaseVert + (intCreate * 22);
		imgCPri[intCreate].width = intCellWidth;
		imgCPri[intCreate].height = 18;
		imgCPri[intCreate].window = colorWindow;
		imgCPri[intCreate].cellID = String(intCreate);
		imgCPri[intCreate].onMouseDown = SetHiLightPri;

		
		txtCPri[intCreate].hOffset = 35 + intCellWidth;
		txtCPri[intCreate].vOffset = intBaseVert + (intCreate * 22) + 12;
	    txtCPri[intCreate].width = intCellWidth - 10;
		txtCPri[intCreate].size = 10;
		txtCPri[intCreate].opacity = 255;
		txtCPri[intCreate].zOrder = 5;
		txtCPri[intCreate].color = strTempPriColor[intCreate];
		txtCPri[intCreate].window = colorWindow;
		txtCPri[intCreate].truncation = "end";
		txtCPri[intCreate].data = strTempPriText[intCreate];
	    txtCPri[intCreate].style.fontFamily = strFontFamily;

		if (intCreate == 10)
		{
			txtCPri[intCreate].data =  "{Unknown Value}";
			txtCPri[intCreate].color = strDefaultBugPriTextColor;
			imgCPri[intCreate].colorize = strDefaultBugPriTextBGColor;
		}
		
		// severity
		imgCSev[intCreate].src = "Resources/bar.png";
		imgCSev[intCreate].colorize = strTempSevBGColor[intCreate];
		imgCSev[intCreate].opacity = 255;
		imgCSev[intCreate].zOrder = 2;
		imgCSev[intCreate].hOffset = 40 + (2 * intCellWidth);
		imgCSev[intCreate].vOffset = intBaseVert + (intCreate * 22);
		imgCSev[intCreate].width = intCellWidth;
		imgCSev[intCreate].height = 18;
		imgCSev[intCreate].window = colorWindow;
		imgCSev[intCreate].cellID = String(intCreate);
		imgCSev[intCreate].onMouseDown = SetHiLightSev;
		
		txtCSev[intCreate].hOffset = 45 + (2 * intCellWidth);
		txtCSev[intCreate].vOffset = intBaseVert + (intCreate * 22) + 12;
	    txtCSev[intCreate].width = intCellWidth - 10;
		txtCSev[intCreate].size = 10;
		txtCSev[intCreate].opacity = 255;
		txtCSev[intCreate].zOrder = 5;
		txtCSev[intCreate].color = strTempSevColor[intCreate];
		txtCSev[intCreate].window = colorWindow;
		txtCSev[intCreate].truncation = "end";
		txtCSev[intCreate].data = strTempSevText[intCreate];
	    txtCSev[intCreate].style.fontFamily = strFontFamily;

		if (intCreate == 10)
		{
			txtCSev[intCreate].data =  "{Unknown Value}";
			txtCSev[intCreate].color = strDefaultBugSevTextColor;
			imgCSev[intCreate].colorize = strDefaultBugSevTextBGColor;
		}
	}
	intCreate = null;

	// bugs assigned to me	
	imgCAssToMe.src = "Resources/bar.png";
	imgCAssToMe.colorize = strBugAssToMeBGColor;
	imgCAssToMe.opacity = 255;
	imgCAssToMe.zOrder = 2;
	imgCAssToMe.hOffset = 20 + parseInt(intCellWidth / 2);
	imgCAssToMe.vOffset = 297;
	imgCAssToMe.width = intCellWidth * 2 + 20;
	imgCAssToMe.height = 18;
	imgCAssToMe.window = colorWindow;
	imgCAssToMe.cellID = "A2M";
	imgCAssToMe.onMouseDown = SetHiLight2Me;

	txtCAssToMe.hOffset = 25 + parseInt(intCellWidth / 2);
	txtCAssToMe.vOffset = 309;
	txtCAssToMe.width = (intCellWidth * 2) - 10 + 20;
	txtCAssToMe.size = 10;
	txtCAssToMe.opacity = 255;
	txtCAssToMe.zOrder = 5;
	txtCAssToMe.color = strBugAssToMeColor;
	txtCAssToMe.window = colorWindow;
	txtCAssToMe.truncation = "end";
	txtCAssToMe.data = "Bugs Assigned To Me";
    txtCAssToMe.style.fontFamily = strFontFamily;

	// instructions
	txtCLabel1.opacity = 255;
	txtCLabel1.zOrder = 3;
	txtCLabel1.vOffset = 335;
	txtCLabel1.hOffset = parseInt(intMasterWidth / 2);
	txtCLabel1.window = colorWindow;
	txtCLabel1.data = "Select a Cell above then Click an Edit Button below:";
	txtCLabel1.size = 11;
	txtCLabel1.alignment = "center";
	txtCLabel1.color = "#ffffff";
    txtCLabel1.style.fontFamily = strFontFamily;
	
	// buttons
	btnCString.src = "Resources/button.png";
	btnCString.colorize = "#29517b";
	btnCString.opacity = 255;
	btnCString.zOrder = 2;
	btnCString.vOffset = txtCLabel1.vOffset + 10;
	btnCString.width = 130;
	btnCString.height = 20;
	btnCString.hOffset = parseInt(intMasterWidth - ((btnCString.width * 3) + 40)) / 2;
	btnCString.window = colorWindow;
	btnCString.onMouseDown = EditStrings;

	btnCStringText.opacity = 255;
	btnCStringText.zOrder = 3;
	btnCStringText.vOffset = btnCString.vOffset + 14;
	btnCStringText.hOffset = btnCString.hOffset + parseInt(btnCString.width / 2);
	btnCStringText.window = colorWindow;
	btnCStringText.data = "Edit Bug Strings";
	btnCStringText.size = 12;
	btnCStringText.alignment = "center";
    btnCStringText.style.fontFamily = strFontFamily;
	
	btnCText.src = "Resources/button.png";
	btnCText.colorize = "#29517b";
	btnCText.opacity = 255;
	btnCText.zOrder = 2;
	btnCText.hOffset = btnCString.hOffset + btnCString.width + 20;
	btnCText.vOffset = btnCString.vOffset;
	btnCText.width = btnCString.width;
	btnCText.height = btnCString.height;
	btnCText.window = colorWindow;
	btnCText.onMouseDown = EditTextColor;

	btnCTextText.opacity = 255;
	btnCTextText.zOrder = 3;
	btnCTextText.vOffset = btnCText.vOffset + 14;
	btnCTextText.hOffset = btnCText.hOffset + parseInt(btnCText.width / 2);
	btnCTextText.window = colorWindow;
	btnCTextText.data = "Edit Text Color";
	btnCTextText.size = 12;
	btnCTextText.alignment = "center";
    btnCTextText.style.fontFamily = strFontFamily;
	
	btnCBackground.src = "Resources/button.png";
	btnCBackground.colorize = "#29517b";
	btnCBackground.opacity = 255;
	btnCBackground.zOrder = 2;
	btnCBackground.hOffset = btnCText.hOffset + btnCText.width + 20;
	btnCBackground.vOffset = btnCString.vOffset;
	btnCBackground.width = btnCString.width;
	btnCBackground.height = btnCString.height;
	btnCBackground.window = colorWindow;
	btnCBackground.onMouseDown = EditBGColor;

	btnCBackgroundText.opacity = 255;
	btnCBackgroundText.zOrder = 3;
	btnCBackgroundText.vOffset = btnCBackground.vOffset + 14;
	btnCBackgroundText.hOffset = btnCBackground.hOffset + parseInt(btnCBackground.width / 2);
	btnCBackgroundText.window = colorWindow;
	btnCBackgroundText.data = "Edit BG Color";
	btnCBackgroundText.size = 12;
	btnCBackgroundText.alignment = "center";
    btnCBackgroundText.style.fontFamily = strFontFamily;

	// instructions - part 2
	txtCLabel2.opacity = 255;
	txtCLabel2.zOrder = 3;
	txtCLabel2.vOffset = btnCBackgroundText.vOffset + 28;
	txtCLabel2.hOffset = parseInt(intMasterWidth / 2);
	txtCLabel2.window = colorWindow;
	txtCLabel2.data = "When Finished, Click Below to Save or Discard Your Changes:";
	txtCLabel2.size = 11;
	txtCLabel2.alignment = "center";
	txtCLabel2.color = "#ffffff";
    txtCLabel2.style.fontFamily = strFontFamily;
	
	// buttons - part 2
	btnCReset.src = "Resources/button.png";
	btnCReset.colorize = "#29517b";
	btnCReset.opacity = 255;
	btnCReset.zOrder = 2;
	btnCReset.vOffset = txtCLabel2.vOffset + 10;
	btnCReset.width = 130;
	btnCReset.height = 20;
	btnCReset.hOffset = parseInt(intMasterWidth - ((btnCReset.width * 3) + 40)) / 2;
	btnCReset.window = colorWindow;
	btnCReset.onMouseDown = DefaultColors;

	btnCResetText.opacity = 255;
	btnCResetText.zOrder = 3;
	btnCResetText.vOffset = btnCReset.vOffset + 13;
	btnCResetText.hOffset = btnCReset.hOffset + parseInt(btnCReset.width / 2);
	btnCResetText.window = colorWindow;
	btnCResetText.data = "Reset ALL to Defaults";
	btnCResetText.size = 10;
	btnCResetText.alignment = "center";
    btnCResetText.style.fontFamily = strFontFamily;
	
	btnCDiscard.src = "Resources/button.png";
	btnCDiscard.colorize = "#29517b";
	btnCDiscard.opacity = 255;
	btnCDiscard.zOrder = 2;
	btnCDiscard.hOffset = btnCReset.hOffset + btnCReset.width + 20;
	btnCDiscard.vOffset = btnCReset.vOffset;
	btnCDiscard.width = btnCReset.width;
	btnCDiscard.height = btnCReset.height;
	btnCDiscard.window = colorWindow;
	btnCDiscard.onMouseDown = DiscardColors;

	btnCDiscardText.opacity = 255;
	btnCDiscardText.zOrder = 3;
	btnCDiscardText.vOffset = btnCDiscard.vOffset + 14;
	btnCDiscardText.hOffset = btnCDiscard.hOffset + parseInt(btnCDiscard.width / 2);
	btnCDiscardText.window = colorWindow;
	btnCDiscardText.data = "Discard Changes";
	btnCDiscardText.size = 12;
	btnCDiscardText.alignment = "center";
    btnCDiscardText.style.fontFamily = strFontFamily;
	
	btnCSave.src = "Resources/button.png";
	btnCSave.colorize = "#29517b";
	btnCSave.opacity = 255;
	btnCSave.zOrder = 2;
	btnCSave.hOffset = btnCDiscard.hOffset + btnCDiscard.width + 20;
	btnCSave.vOffset = btnCReset.vOffset;
	btnCSave.width = btnCReset.width;
	btnCSave.height = btnCReset.height;
	btnCSave.window = colorWindow;
	btnCSave.onMouseDown = SaveColors;

	btnCSaveText.opacity = 255;
	btnCSaveText.zOrder = 3;
	btnCSaveText.vOffset = btnCSave.vOffset + 14;
	btnCSaveText.hOffset = btnCSave.hOffset + parseInt(btnCSave.width / 2);
	btnCSaveText.window = colorWindow;
	btnCSaveText.data = "Save Changes";
	btnCSaveText.size = 12;
	btnCSaveText.alignment = "center";
    btnCSaveText.style.fontFamily = strFontFamily;

	// clear arrays
	strTempPriText = [];
	strTempPriColor = [];
	strTempPriBGColor = [];
	strTempSevPriText = [];
	strTempSevColor = [];
	strTempSevBGColor = [];
	strTempStaText = [];
	strTempStaPriColor = [];
	strTempStaBGColor = [];

	// hide the main window
	mainWindow.visible = "0";

	// Resize the color window
	colorWindow.height = 480;
	colorWindow.width = 500;
	
	// Update the application shadow
	colorWindow.recalcShadow();

	// show the color window
	colorWindow.visible = "1";
		
	// update the GUI
	resumeUpdates();
	updateNow();
	mainWindow.opacity = "0";
}

function DefaultColors()
{
	var intReturn;
	intReturn = alert("This will reset ALL colors and strings to their Default Values.  All customizations will be lost!\n\nAre you absolutely sure?!?", "Yes", "No");
	if (intReturn == 1)
	{
		// set all colors back to defaults
		preferences.PT0.value = preferences.PT0.defaultValue;
		preferences.PT1.value = preferences.PT1.defaultValue;
		preferences.PT2.value = preferences.PT2.defaultValue;
		preferences.PT3.value = preferences.PT3.defaultValue;
		preferences.PT4.value = preferences.PT4.defaultValue;
		preferences.PT5.value = preferences.PT5.defaultValue;
		preferences.PT6.value = preferences.PT6.defaultValue;
		preferences.PT7.value = preferences.PT7.defaultValue;
		preferences.PT8.value = preferences.PT8.defaultValue;
		preferences.PT9.value = preferences.PT9.defaultValue;
		preferences.PC0.value = preferences.PC0.defaultValue;
		preferences.PC1.value = preferences.PC1.defaultValue;
		preferences.PC2.value = preferences.PC2.defaultValue;
		preferences.PC3.value = preferences.PC3.defaultValue;
		preferences.PC4.value = preferences.PC4.defaultValue;
		preferences.PC5.value = preferences.PC5.defaultValue;
		preferences.PC6.value = preferences.PC6.defaultValue;
		preferences.PC7.value = preferences.PC7.defaultValue;
		preferences.PC8.value = preferences.PC8.defaultValue;
		preferences.PC9.value = preferences.PC9.defaultValue;
		preferences.PB0.value = preferences.PB0.defaultValue;
		preferences.PB1.value = preferences.PB1.defaultValue;
		preferences.PB2.value = preferences.PB2.defaultValue;
		preferences.PB3.value = preferences.PB3.defaultValue;
		preferences.PB4.value = preferences.PB4.defaultValue;
		preferences.PB5.value = preferences.PB5.defaultValue;
		preferences.PB6.value = preferences.PB6.defaultValue;
		preferences.PB7.value = preferences.PB7.defaultValue;
		preferences.PB8.value = preferences.PB8.defaultValue;
		preferences.PB9.value = preferences.PB9.defaultValue;
		preferences.VT0.value = preferences.VT0.defaultValue;
		preferences.VT1.value = preferences.VT1.defaultValue;
		preferences.VT2.value = preferences.VT2.defaultValue;
		preferences.VT3.value = preferences.VT3.defaultValue;
		preferences.VT4.value = preferences.VT4.defaultValue;
		preferences.VT5.value = preferences.VT5.defaultValue;
		preferences.VT6.value = preferences.VT6.defaultValue;
		preferences.VT7.value = preferences.VT7.defaultValue;
		preferences.VT8.value = preferences.VT8.defaultValue;
		preferences.VT9.value = preferences.VT9.defaultValue;
		preferences.VC0.value = preferences.VC0.defaultValue;
		preferences.VC1.value = preferences.VC1.defaultValue;
		preferences.VC2.value = preferences.VC2.defaultValue;
		preferences.VC3.value = preferences.VC3.defaultValue;
		preferences.VC4.value = preferences.VC4.defaultValue;
		preferences.VC5.value = preferences.VC5.defaultValue;
		preferences.VC6.value = preferences.VC6.defaultValue;
		preferences.VC7.value = preferences.VC7.defaultValue;
		preferences.VC8.value = preferences.VC8.defaultValue;
		preferences.VC9.value = preferences.VC9.defaultValue;
		preferences.VB0.value = preferences.VB0.defaultValue;
		preferences.VB1.value = preferences.VB1.defaultValue;
		preferences.VB2.value = preferences.VB2.defaultValue;
		preferences.VB3.value = preferences.VB3.defaultValue;
		preferences.VB4.value = preferences.VB4.defaultValue;
		preferences.VB5.value = preferences.VB5.defaultValue;
		preferences.VB6.value = preferences.VB6.defaultValue;
		preferences.VB7.value = preferences.VB7.defaultValue;
		preferences.VB8.value = preferences.VB8.defaultValue;
		preferences.VB9.value = preferences.VB9.defaultValue;
		preferences.ST0.value = preferences.ST0.defaultValue;
		preferences.ST1.value = preferences.ST1.defaultValue;
		preferences.ST2.value = preferences.ST2.defaultValue;
		preferences.ST3.value = preferences.ST3.defaultValue;
		preferences.ST4.value = preferences.ST4.defaultValue;
		preferences.ST5.value = preferences.ST5.defaultValue;
		preferences.ST6.value = preferences.ST6.defaultValue;
		preferences.ST7.value = preferences.ST7.defaultValue;
		preferences.ST8.value = preferences.ST8.defaultValue;
		preferences.ST9.value = preferences.ST9.defaultValue;
		preferences.SC0.value = preferences.SC0.defaultValue;
		preferences.SC1.value = preferences.SC1.defaultValue;
		preferences.SC2.value = preferences.SC2.defaultValue;
		preferences.SC3.value = preferences.SC3.defaultValue;
		preferences.SC4.value = preferences.SC4.defaultValue;
		preferences.SC5.value = preferences.SC5.defaultValue;
		preferences.SC6.value = preferences.SC6.defaultValue;
		preferences.SC7.value = preferences.SC7.defaultValue;
		preferences.SC8.value = preferences.SC8.defaultValue;
		preferences.SC9.value = preferences.SC9.defaultValue;
		preferences.SB0.value = preferences.SB0.defaultValue;
		preferences.SB1.value = preferences.SB1.defaultValue;
		preferences.SB2.value = preferences.SB2.defaultValue;
		preferences.SB3.value = preferences.SB3.defaultValue;
		preferences.SB4.value = preferences.SB4.defaultValue;
		preferences.SB5.value = preferences.SB5.defaultValue;
		preferences.SB6.value = preferences.SB6.defaultValue;
		preferences.SB7.value = preferences.SB7.defaultValue;
		preferences.SB8.value = preferences.SB8.defaultValue;
		preferences.SB9.value = preferences.SB9.defaultValue;
		preferences.SCDEFAULT.value = preferences.SCDEFAULT.defaultValue;
		preferences.SBDEFAULT.value = preferences.SBDEFAULT.defaultValue;
		preferences.ASSTOMECOLOR.value = preferences.ASSTOMECOLOR.defaultValue;
		preferences.ASSTOMEBGCOLOR.value = preferences.ASSTOMEBGCOLOR.defaultValue;
		preferences.PCDEFAULT.value = preferences.PCDEFAULT.defaultValue;
		preferences.PBDEFAULT.value = preferences.PBDEFAULT.defaultValue;
		preferences.VCDEFAULT.value = preferences.VCDEFAULT.defaultValue;
		preferences.VBDEFAULT.value = preferences.VBDEFAULT.defaultValue;
		
		// rebuild the color tables
		LoadColors();

		// rebuild the current bug display
		LoadBugs(urlInput);

		// hide the color window
		colorWindow.visible = "0";
		
		// show the main window
		mainWindow.visible = "1";
		mainWindow.opacity = "255";
		
		// reset and retart the update timer
		tmrRefresh.reset();
		tmrRefresh.ticking = "true";
	}
}

function DiscardColors()
{
	// hide the color window
	colorWindow.visible = "0";
	
	// show the main window
	mainWindow.visible = "1";
	mainWindow.opacity = "255";
	
	// reset and retart the update timer
	tmrRefresh.reset();
	tmrRefresh.ticking = "true";
}

function SaveColors()
{
	// save control values into preferences
	preferences.PT0.value = txtCPri[0].data;
	preferences.PT1.value = txtCPri[1].data;
	preferences.PT2.value = txtCPri[2].data;
	preferences.PT3.value = txtCPri[3].data;
	preferences.PT4.value = txtCPri[4].data;
	preferences.PT5.value = txtCPri[5].data;
	preferences.PT6.value = txtCPri[6].data;
	preferences.PT7.value = txtCPri[7].data;
	preferences.PT8.value = txtCPri[8].data;
	preferences.PT9.value = txtCPri[9].data;
	preferences.PC0.value = txtCPri[0].color;
	preferences.PC1.value = txtCPri[1].color;
	preferences.PC2.value = txtCPri[2].color;
	preferences.PC3.value = txtCPri[3].color;
	preferences.PC4.value = txtCPri[4].color;
	preferences.PC5.value = txtCPri[5].color;
	preferences.PC6.value = txtCPri[6].color;
	preferences.PC7.value = txtCPri[7].color;
	preferences.PC8.value = txtCPri[8].color;
	preferences.PC9.value = txtCPri[9].color;
	preferences.PB0.value = imgCPri[0].colorize;
	preferences.PB1.value = imgCPri[1].colorize;
	preferences.PB2.value = imgCPri[2].colorize;
	preferences.PB3.value = imgCPri[3].colorize;
	preferences.PB4.value = imgCPri[4].colorize;
	preferences.PB5.value = imgCPri[5].colorize;
	preferences.PB6.value = imgCPri[6].colorize;
	preferences.PB7.value = imgCPri[7].colorize;
	preferences.PB8.value = imgCPri[8].colorize;
	preferences.PB9.value = imgCPri[9].colorize;
	preferences.VT0.value = txtCSev[0].data;
	preferences.VT1.value = txtCSev[1].data;
	preferences.VT2.value = txtCSev[2].data;
	preferences.VT3.value = txtCSev[3].data;
	preferences.VT4.value = txtCSev[4].data;
	preferences.VT5.value = txtCSev[5].data;
	preferences.VT6.value = txtCSev[6].data;
	preferences.VT7.value = txtCSev[7].data;
	preferences.VT8.value = txtCSev[8].data;
	preferences.VT9.value = txtCSev[9].data;
	preferences.VC0.value = txtCSev[0].color;
	preferences.VC1.value = txtCSev[1].color;
	preferences.VC2.value = txtCSev[2].color;
	preferences.VC3.value = txtCSev[3].color;
	preferences.VC4.value = txtCSev[4].color;
	preferences.VC5.value = txtCSev[5].color;
	preferences.VC6.value = txtCSev[6].color;
	preferences.VC7.value = txtCSev[7].color;
	preferences.VC8.value = txtCSev[8].color;
	preferences.VC9.value = txtCSev[9].color;
	preferences.VB0.value = imgCSev[0].colorize;
	preferences.VB1.value = imgCSev[1].colorize;
	preferences.VB2.value = imgCSev[2].colorize;
	preferences.VB3.value = imgCSev[3].colorize;
	preferences.VB4.value = imgCSev[4].colorize;
	preferences.VB5.value = imgCSev[5].colorize;
	preferences.VB6.value = imgCSev[6].colorize;
	preferences.VB7.value = imgCSev[7].colorize;
	preferences.VB8.value = imgCSev[8].colorize;
	preferences.VB9.value = imgCSev[9].colorize;
	preferences.ST0.value = txtCSta[0].data;
	preferences.ST1.value = txtCSta[1].data;
	preferences.ST2.value = txtCSta[2].data;
	preferences.ST3.value = txtCSta[3].data;
	preferences.ST4.value = txtCSta[4].data;
	preferences.ST5.value = txtCSta[5].data;
	preferences.ST6.value = txtCSta[6].data;
	preferences.ST7.value = txtCSta[7].data;
	preferences.ST8.value = txtCSta[8].data;
	preferences.ST9.value = txtCSta[9].data;
	preferences.SC0.value = txtCSta[0].data;
	preferences.SC1.value = txtCSta[1].color;
	preferences.SC2.value = txtCSta[2].color;
	preferences.SC3.value = txtCSta[3].color;
	preferences.SC4.value = txtCSta[4].color;
	preferences.SC5.value = txtCSta[5].color;
	preferences.SC6.value = txtCSta[6].color;
	preferences.SC7.value = txtCSta[7].color;
	preferences.SC8.value = txtCSta[8].color;
	preferences.SC9.value = txtCSta[9].color;
	preferences.SB0.value = imgCSta[0].colorize;
	preferences.SB1.value = imgCSta[1].colorize;
	preferences.SB2.value = imgCSta[2].colorize;
	preferences.SB3.value = imgCSta[3].colorize;
	preferences.SB4.value = imgCSta[4].colorize;
	preferences.SB5.value = imgCSta[5].colorize;
	preferences.SB6.value = imgCSta[6].colorize;
	preferences.SB7.value = imgCSta[7].colorize;
	preferences.SB8.value = imgCSta[8].colorize;
	preferences.SB9.value = imgCSta[9].colorize;
	preferences.SCDEFAULT.value = txtCSta[10].color;
	preferences.SBDEFAULT.value = imgCSta[10].colorize;
	preferences.ASSTOMECOLOR.value = txtCAssToMe.color;
	preferences.ASSTOMEBGCOLOR.value = imgCAssToMe.colorize;
	preferences.PCDEFAULT.value = txtCPri[10].color;
	preferences.PBDEFAULT.value = imgCPri[10].colorize;
	preferences.VCDEFAULT.value = txtCSev[10].color;
	preferences.VBDEFAULT.value = imgCSev[10].colorize;

	// rebuild the color tables
	LoadColors();
	
	// rebuild the current bug display
	LoadBugs(urlInput);
	
	// hide the color window
	colorWindow.visible = "0";
	
	// show the main window
	mainWindow.visible = "1";
	mainWindow.opacity = "255";
	
	// reset and retart the update timer
	tmrRefresh.reset();
	tmrRefresh.ticking = "true";
}

function EditStrings()
{
	// edit bug strings
	if (strCSelectedItem.length > 0)
	{
		// find the selected cell
		var strCType = Left(strCSelectedItem, 1);
		var intCLoc = parseInt(strCSelectedItem.substring(1));
		var strReturn;
		var strCurrentVal;
		var strPrompt;
		var strDispType;
		var strNewValue = "";

		// don't allow edit of {unknown item} strings
		if (intCLoc < 10)
		{
			if ((strCType == "P") || (strCType == "V"))
			{
				if (strCType == "P")
				{
					strCurrentVal = txtCPri[intCLoc].data;
					strDispType = "Priority";
				}
				else
				{
					strCurrentVal = txtCSev[intCLoc].data;
					strDispType = "Severity";
				}
				strPrompt = "Bugs with " + strDispType + " values starting with the following string(s) will use this color-coding:\n\n(Comma-separated list of strings, Leading/trailing spaces removed,\nTruncated to 4 chars, Upper-cased, 5 strings maximum...)\n\n";
				
				// work-around to prevent main window from popping up when prompting
			    suppressUpdates();
				mainWindow.opacity = "0";
				mainWindow.visible = "0";
				strReturn = prompt(strPrompt, strCurrentVal, "Edit Bug Strings", "Save", "Discard");
				resumeUpdates();
				
				if (strReturn != undefined)
				{
					// scrub the values in the string
					var intNumStringsInList = 0;
					var blnTooMany = false;
					var strTemp = [];
					var intLoopy;
					strTemp = String(strReturn).split(",");
					//  for each split item
					for (intLoopy = 0; intLoopy < strTemp.length; intLoopy++)
					{
						// remove leading and trailing spaces
						strTemp[intLoopy] = Trim(strTemp[intLoopy]);
						// truncate to 4 characters if longer
						if (strTemp[intLoopy].length > 4)
						{
							strTemp[intLoopy] = Left(strTemp[intLoopy], 4);
						}
						// upper case the string
						if (strTemp[intLoopy].length > 0)
						{
							strTemp[intLoopy] = strTemp[intLoopy].toUpperCase();
						}
						// if there's anything left in the string and we haven't added 5 already
						if (strTemp[intLoopy].length > 0)
						{
							if (intNumStringsInList < 5)
							{
								strNewValue = strNewValue + strTemp[intLoopy] + ",";
								intNumStringsInList = intNumStringsInList + 1;
							}
							else
							{
								// already added 5 items
								blnTooMany = true;
							}
						}
					}
					
					// remove trailing comma, if present
					if (Right(strNewValue, 1) == ",")
					{
						strNewValue = Left(strNewValue, (strNewValue.length - 1));
					}
					
					// save the rebuilt string
					if (strCType == "P")
					{
						txtCPri[intCLoc].data = strNewValue;
					}
					else
					{
						txtCSev[intCLoc].data = strNewValue;
					}
					
					// display truncation warning
					if (blnTooMany == true)
					{
						alert("You many only have 5 strings per entry.  Extra strings have been discarded.");
					}
				}
			}
		}
	}
}

function EditTextColor()
{
	if (strCSelectedItem.length > 0)
	{
		// find the selected cell
		var strCType = Left(strCSelectedItem, 1);
		var intCLoc = parseInt(strCSelectedItem.substring(1));
		var strReturn;
		switch (strCType)
		{
			case "S":
				strReturn = chooseColor(txtCSta[intCLoc].color);	
				if (strReturn != false)
				{
					txtCSta[intCLoc].color = strReturn;
				}
				break;
			case "P":
				strReturn = chooseColor(txtCPri[intCLoc].color);	
				if (strReturn != false)
				{
					txtCPri[intCLoc].color = strReturn;
				}
				break;
			case "V":
				strReturn = chooseColor(txtCSev[intCLoc].color);	
				if (strReturn != false)
				{
					txtCSev[intCLoc].color = strReturn;
				}
				break;
			case "A":
				strReturn = chooseColor(txtCAssToMe.color);	
				if (strReturn != false)
				{
					txtCAssToMe.color = strReturn;
				}
				break;
		}
	}
}

function EditBGColor()
{
	if (strCSelectedItem.length > 0)
	{
		// find the selected cell
		var strCType = Left(strCSelectedItem, 1);
		var intCLoc = parseInt(strCSelectedItem.substring(1));
		var strReturn;
		switch (strCType)
		{
			case "S":
				strReturn = chooseColor(imgCSta[intCLoc].colorize);	
				if (strReturn != false)
				{
					imgCSta[intCLoc].colorize = strReturn;
				}
				break;
			case "P":
				strReturn = chooseColor(imgCPri[intCLoc].colorize);
				if (strReturn != false)
				{
					imgCPri[intCLoc].colorize = strReturn;
				}
				break;
			case "V":
				strReturn = chooseColor(imgCSev[intCLoc].colorize);	
				if (strReturn != false)
				{
					imgCSev[intCLoc].colorize = strReturn;
				}
				break;
			case "A":
				strReturn = chooseColor(imgCAssToMe.colorize);	
				if (strReturn != false)
				{
					imgCAssToMe.colorize = strReturn;
				}
				break;
		}
	}
}

function SetHiLightPri( )
{
    if (this.cellID)
	{
		SetHiLight("P" + this.cellID);
	}
}

function SetHiLightSev( )
{
    if (this.cellID)
	{
		SetHiLight("V" + this.cellID);
	}
}

function SetHiLightSta( )
{
    if (this.cellID)
	{
		SetHiLight("S" + this.cellID);
	}
}

function SetHiLight2Me( )
{
    if (this.cellID)
	{
		SetHiLight(this.cellID);
	}
}

function SetHiLight(strCell)
{
	// toggle highlight on the clicked cell
	if (strCSelectedItem == strCell)
	{
		// cell is already highlighted
		// turn highlight off for cell
		strCSelectedItem = "";
		imgCHiLite.visible = "0";
	}
	else
	{
		// cell is not highlighted
		// turn off old highlight (if valid)
		if (strCSelectedItem.Length > 0)
		{
			strCSelectedItem = "";
			imgCHiLite.visible = "0";
		}
		
		// turn on highlight for new cell
		var strCType = Left(strCell, 1);
		var intCLoc = parseInt(strCell.substring(1));
		imgCHiLite.src = "Resources/highlight.png";
		imgCHiLite.opacity = 255;
		imgCHiLite.zOrder = 1;
		imgCHiLite.window = colorWindow;
		
		switch (strCType)
		{
			case "S":
				imgCHiLite.hOffset = imgCSta[intCLoc].hOffset - 3;
				imgCHiLite.vOffset = imgCSta[intCLoc].vOffset - 3;
				imgCHiLite.height = imgCSta[intCLoc].height + 6;
				imgCHiLite.width = imgCSta[intCLoc].width + 6;
				break;
			case "P":
				imgCHiLite.hOffset = imgCPri[intCLoc].hOffset - 3;
				imgCHiLite.vOffset = imgCPri[intCLoc].vOffset - 3;
				imgCHiLite.height = imgCPri[intCLoc].height + 6;
				imgCHiLite.width = imgCPri[intCLoc].width + 6;
				break;
			case "V":
				imgCHiLite.hOffset = imgCSev[intCLoc].hOffset - 3;
				imgCHiLite.vOffset = imgCSev[intCLoc].vOffset - 3;
				imgCHiLite.height = imgCSev[intCLoc].height + 6;
				imgCHiLite.width = imgCSev[intCLoc].width + 6;
				break;
			case "A":
				imgCHiLite.hOffset = imgCAssToMe.hOffset - 3;
				imgCHiLite.vOffset = imgCAssToMe.vOffset - 3;
				imgCHiLite.height = imgCAssToMe.height + 6;
				imgCHiLite.width = imgCAssToMe.width + 6;
				break;
		}
		imgCHiLite.visible = "1";
		strCSelectedItem = strCell;
	}
}

function CheckForNewVersion(intChatty)
{
	//intChatty: 0 = only display info if new version found, 1 = display info even if same version is found (and also force a check over preferences setting)
	// run if Disable Version Check Pref not checked
	if ((preferences.NONEWCHECK.value == "0") || (intChatty == 1))
	{
		var strBugMonGalleryPage = "http://widgets.yahoo.com/gallery/view.php?widget=41978";
		// stop the timer
		tmrRefresh.ticking = "false";

		// set versions
		var strWebSiteVersion = "none";
		var strCurrentVersion = widget.version;
		var strLastNotifiedVersion = preferences.LASTWARNEDVERSION.value;

		// create the URL
		var urlLookup = new URL();
		urlLookup.location = strBugMonGalleryPage;

		// load web site
		var strServerData = "";
		try
		{
			urlLookup.fetch();
			strServerData = urlLookup.result;
		}
		catch (e)
		{
		}
		// parse version from website
		if(strServerData.length > 0)
		{
			var m = null;
			try
			{
			  	var theRegEx = /(class=\"widgetblock_version\">Version)(.*?)(- Update)(.*?)(<\/td>)/;
			  	var theRegEx2 = /(class=\"widgetblock_version\">Version)(.*?)(- Added)(.*?)(<\/td>)/;
			  	m = theRegEx.exec(strServerData);
		    	if (m != null)
				{
				  	strWebSiteVersion = Trim(RegExp.$2);  	
				}
				else
				{
				  	m = theRegEx2.exec(data);
			    	if (m != null)
					{
					  	strWebSiteVersion = Trim(RegExp.$2);  	
					}
				}
			}
			catch (e)
			{
			}
		}

		var intAnswer;
		if ((strWebSiteVersion != "none") && (strWebSiteVersion.length > 0))
		{
			// if website version <> current version
			if (String(strCurrentVersion) != String(strWebSiteVersion))
			{
				// if website version <> last notified version
				if ((String(strLastNotifiedVersion) != String(strWebSiteVersion)) || (intChatty == 1))
				{
					// save website version as last notified version
					preferences.LASTWARNEDVERSION.value = strWebSiteVersion;

					// display update alert
					intAnswer = alert("A newer version of BugMon is now available.\n\n     Current Version:\t" + strCurrentVersion + "\n     Updated Version:\t" + strWebSiteVersion + "\n\nDo you wish to go to the Widget Gallery to download the new version?\n\n(You will not be notified again for this release...)", "Yes", "No");
					if (intAnswer == 1)
					{
						// launch website in new browser, if yes
						openURL(strBugMonGalleryPage);
					}
				}
			}
			else
			{
				if (intChatty == 1)
				{
					intAnswer = alert("You have the most recent version of BugMon.\n\n     Current Version:\t" + strCurrentVersion + "\n\nDo you wish to go to the Widget Gallery anyway?\n(To leave a comment, suggestion, etc...)\n", "Yes", "No");
					if (intAnswer == 1)
					{
						// launch website in new browser, if yes
						openURL(strBugMonGalleryPage);
					}
				}
			}
		}

		// clean up URL to prevent memory leak
		try
		{
			urlLookup.clear();
			urlLookup = null;
			delete urlLookup;
		}
		catch(e)
		{
		}
		
		// reset the timer
		tmrRefresh.reset();
		
		// start the timer
		tmrRefresh.ticking = "true";
	}
}

function UnEscapeToo(strURLText, intLevel)
{
	// Level 0 = quick scrub, 1= scrub EVERYTHING
	strURLText = strURLText.replace(/&#33;/ig,"!");
	strURLText = strURLText.replace(/&#033;/ig,"!");
	strURLText = strURLText.replace(/&quot;/ig,"\"");
	strURLText = strURLText.replace(/&#34;/ig,"\"");
	strURLText = strURLText.replace(/&#034;/ig,"\"");
	strURLText = strURLText.replace(/&#36;/ig,"$");
	strURLText = strURLText.replace(/&#036;/ig,"$");
	strURLText = strURLText.replace(/&amp;/ig,"&");
	strURLText = strURLText.replace(/&#38;/ig,"&");
	strURLText = strURLText.replace(/&#038;/ig,"&");
	strURLText = strURLText.replace(/&apos;/ig,"'");
	strURLText = strURLText.replace(/&#39;/ig,"'");
	strURLText = strURLText.replace(/&#039;/ig,"'");
	strURLText = strURLText.replace(/&lt;/ig,"<");
	strURLText = strURLText.replace(/&#60;/ig,"<");
	strURLText = strURLText.replace(/&#060;/ig,"<");
	strURLText = strURLText.replace(/&gt;/ig,">");
	strURLText = strURLText.replace(/&#62;/ig,">");
	strURLText = strURLText.replace(/&#062;/ig,">");
	strURLText = strURLText.replace(/&#64;/ig,"@");
	strURLText = strURLText.replace(/&#064;/ig,"@");
	strURLText = strURLText.replace(/&#92;/ig,"\\");
	strURLText = strURLText.replace(/&#092;/ig,"\\");
	if (intLevel != 0)
	{
		strURLText = strURLText.replace(/&euro;/ig,"");
		strURLText = strURLText.replace(/&#128;/ig,"");
		strURLText = strURLText.replace(/&#8364;/ig,"");
		strURLText = strURLText.replace(/&sbquo;/ig,"");
		strURLText = strURLText.replace(/&#130;/ig,"");
		strURLText = strURLText.replace(/&#8218;/ig,"");
		strURLText = strURLText.replace(/&fnof;/ig,"");
		strURLText = strURLText.replace(/&#131;/ig,"");
		strURLText = strURLText.replace(/&#402;/ig,"");
		strURLText = strURLText.replace(/&bdquo;/ig,"");
		strURLText = strURLText.replace(/&#132;/ig,"");
		strURLText = strURLText.replace(/&#8222;/ig,"");
		strURLText = strURLText.replace(/&hellip;/ig,"");
		strURLText = strURLText.replace(/&#133;/ig,"");
		strURLText = strURLText.replace(/&#8230;/ig,"");
		strURLText = strURLText.replace(/&dagger;/ig,"");
		strURLText = strURLText.replace(/&#134;/ig,"");
		strURLText = strURLText.replace(/&#8224;/ig,"");
		strURLText = strURLText.replace(/&Dagger;/ig,"");
		strURLText = strURLText.replace(/&#135;/ig,"");
		strURLText = strURLText.replace(/&#8225;/ig,"");
		strURLText = strURLText.replace(/&circ;/ig,"");
		strURLText = strURLText.replace(/&#136;/ig,"");
		strURLText = strURLText.replace(/&#710;/ig,"");
		strURLText = strURLText.replace(/&permil;/ig,"");
		strURLText = strURLText.replace(/&#137;/ig,"");
		strURLText = strURLText.replace(/&#8240;/ig,"");
		strURLText = strURLText.replace(/&Scaron;/ig,"");
		strURLText = strURLText.replace(/&#138;/ig,"");
		strURLText = strURLText.replace(/&#352;/ig,"");
		strURLText = strURLText.replace(/&lsaquo;/ig,"");
		strURLText = strURLText.replace(/&#139;/ig,"");
		strURLText = strURLText.replace(/&#8249;/ig,"");
		strURLText = strURLText.replace(/&OElig;/ig,"");
		strURLText = strURLText.replace(/&#140;/ig,"");
		strURLText = strURLText.replace(/&#338;/ig,"");
		strURLText = strURLText.replace(/&#142;/ig,"");
		strURLText = strURLText.replace(/&lsquo;/ig,"");
		strURLText = strURLText.replace(/&#145;/ig,"");
		strURLText = strURLText.replace(/&#8216;/ig,"");
		strURLText = strURLText.replace(/&rsquo;/ig,"");
		strURLText = strURLText.replace(/&#146;/ig,"");
		strURLText = strURLText.replace(/&#8217;/ig,"");
		strURLText = strURLText.replace(/&ldquo;/ig,"");
		strURLText = strURLText.replace(/&#147;/ig,"");
		strURLText = strURLText.replace(/&#8220;/ig,"");
		strURLText = strURLText.replace(/&rdquo;/ig,"");
		strURLText = strURLText.replace(/&#148;/ig,"");
		strURLText = strURLText.replace(/&#8221;/ig,"");
		strURLText = strURLText.replace(/&bull;/ig,"");
		strURLText = strURLText.replace(/&#149;/ig,"");
		strURLText = strURLText.replace(/&#8226;/ig,"");
		strURLText = strURLText.replace(/&ndash;/ig,"");
		strURLText = strURLText.replace(/&#150;/ig,"");
		strURLText = strURLText.replace(/&#8211;/ig,"");
		strURLText = strURLText.replace(/&mdash;/ig,"");
		strURLText = strURLText.replace(/&#151;/ig,"");
		strURLText = strURLText.replace(/&#8212;/ig,"");
		strURLText = strURLText.replace(/&tilde;/ig,"");
		strURLText = strURLText.replace(/&#152;/ig,"");
		strURLText = strURLText.replace(/&#732;/ig,"");
		strURLText = strURLText.replace(/&trade;/ig,"");
		strURLText = strURLText.replace(/&#153;/ig,"");
		strURLText = strURLText.replace(/&#8482;/ig,"");
		strURLText = strURLText.replace(/&scaron;/ig,"");
		strURLText = strURLText.replace(/&#154;/ig,"");
		strURLText = strURLText.replace(/&#353;/ig,"");
		strURLText = strURLText.replace(/&rsaquo;/ig,"");
		strURLText = strURLText.replace(/&#155;/ig,"");
		strURLText = strURLText.replace(/&#8250;/ig,"");
		strURLText = strURLText.replace(/&oelig;/ig,"");
		strURLText = strURLText.replace(/&#156;/ig,"");
		strURLText = strURLText.replace(/&#339;/ig,"");
		strURLText = strURLText.replace(/&#158;/ig,"");
		strURLText = strURLText.replace(/&Yuml;/ig,"");
		strURLText = strURLText.replace(/&#159;/ig,"");
		strURLText = strURLText.replace(/&#376;/ig,"");
		strURLText = strURLText.replace(/&nbsp;/ig,"");
		strURLText = strURLText.replace(/&#160;/ig,"");
		strURLText = strURLText.replace(/&iexcl;/ig,"");
		strURLText = strURLText.replace(/&#161;/ig,"");
		strURLText = strURLText.replace(/&cent;/ig,"");
		strURLText = strURLText.replace(/&#162;/ig,"");
		strURLText = strURLText.replace(/&pound;/ig,"");
		strURLText = strURLText.replace(/&#163;/ig,"");
		strURLText = strURLText.replace(/&curren;/ig,"");
		strURLText = strURLText.replace(/&#164;/ig,"");
		strURLText = strURLText.replace(/&yen;/ig,"");
		strURLText = strURLText.replace(/&#165;/ig,"");
		strURLText = strURLText.replace(/&brvbar;/ig,"");
		strURLText = strURLText.replace(/&#166;/ig,"");
		strURLText = strURLText.replace(/&sect;/ig,"");
		strURLText = strURLText.replace(/&#167;/ig,"");
		strURLText = strURLText.replace(/&uml;/ig,"");
		strURLText = strURLText.replace(/&#168;/ig,"");
		strURLText = strURLText.replace(/&copy;/ig,"");
		strURLText = strURLText.replace(/&#169;/ig,"");
		strURLText = strURLText.replace(/&ordf;/ig,"");
		strURLText = strURLText.replace(/&#170;/ig,"");
		strURLText = strURLText.replace(/&laquo;/ig,"");
		strURLText = strURLText.replace(/&#171;/ig,"");
		strURLText = strURLText.replace(/&not;/ig,"");
		strURLText = strURLText.replace(/&#172;/ig,"");
		strURLText = strURLText.replace(/&shy;/ig,"");
		strURLText = strURLText.replace(/&#173;/ig,"");
		strURLText = strURLText.replace(/&reg;/ig,"");
		strURLText = strURLText.replace(/&#174;/ig,"");
		strURLText = strURLText.replace(/&macr;/ig,"");
		strURLText = strURLText.replace(/&#175;/ig,"");
		strURLText = strURLText.replace(/&deg;/ig,"");
		strURLText = strURLText.replace(/&#176;/ig,"");	
		strURLText = strURLText.replace(/&plusmn;/ig,"");
		strURLText = strURLText.replace(/&#177;/ig,"");
		strURLText = strURLText.replace(/&sup2;/ig,"");
		strURLText = strURLText.replace(/&#178;/ig,"");
		strURLText = strURLText.replace(/&sup3;/ig,"");
		strURLText = strURLText.replace(/&#179;/ig,"");
		strURLText = strURLText.replace(/&acute;/ig,"");
		strURLText = strURLText.replace(/&#180;/ig,"");
		strURLText = strURLText.replace(/&micro;/ig,"");
		strURLText = strURLText.replace(/&#181;/ig,"");
		strURLText = strURLText.replace(/&para;/ig,"");
		strURLText = strURLText.replace(/&#182;/ig,"");
		strURLText = strURLText.replace(/&middot;/ig,"");
		strURLText = strURLText.replace(/&#183;/ig,"");
		strURLText = strURLText.replace(/&cedil;/ig,"");
		strURLText = strURLText.replace(/&#184;/ig,"");
		strURLText = strURLText.replace(/&sup1;/ig,"");
		strURLText = strURLText.replace(/&#185;/ig,"");
		strURLText = strURLText.replace(/&ordm;/ig,"");
		strURLText = strURLText.replace(/&#186;/ig,"");
		strURLText = strURLText.replace(/&raquo;/ig,"");
		strURLText = strURLText.replace(/&#187;/ig,"");
		strURLText = strURLText.replace(/&frac14;/ig,"");
		strURLText = strURLText.replace(/&#188;/ig,"");
		strURLText = strURLText.replace(/&frac12;/ig,"");
		strURLText = strURLText.replace(/&#189;/ig,"");
		strURLText = strURLText.replace(/&frac34;/ig,"");
		strURLText = strURLText.replace(/&#190;/ig,"");
		strURLText = strURLText.replace(/&iquest;/ig,"");
		strURLText = strURLText.replace(/&#191;/ig,"");
		strURLText = strURLText.replace(/&Agrave;/ig,"");
		strURLText = strURLText.replace(/&#192;/ig,"");
		strURLText = strURLText.replace(/&Aacute;/ig,"");
		strURLText = strURLText.replace(/&#193;/ig,"");
		strURLText = strURLText.replace(/&Acirc;/ig,"");
		strURLText = strURLText.replace(/&#194;/ig,"");
		strURLText = strURLText.replace(/&Atilde;/ig,"");
		strURLText = strURLText.replace(/&#195;/ig,"");
		strURLText = strURLText.replace(/&Auml;/ig,"");
		strURLText = strURLText.replace(/&#196;/ig,"");
		strURLText = strURLText.replace(/&Aring;/ig,"");
		strURLText = strURLText.replace(/&#197;/ig,"");
		strURLText = strURLText.replace(/&AElig;/ig,"");
		strURLText = strURLText.replace(/&#198;/ig,"");
		strURLText = strURLText.replace(/&Ccedil;/ig,"");
		strURLText = strURLText.replace(/&#199;/ig,"");
		strURLText = strURLText.replace(/&Egrave;/ig,"");
		strURLText = strURLText.replace(/&#200;/ig,"");
		strURLText = strURLText.replace(/&Eacute;/ig,"");
		strURLText = strURLText.replace(/&#201;/ig,"");
		strURLText = strURLText.replace(/&Ecirc;/ig,"");
		strURLText = strURLText.replace(/&#202;/ig,"");
		strURLText = strURLText.replace(/&Euml;/ig,"");
		strURLText = strURLText.replace(/&#203;/ig,"");
		strURLText = strURLText.replace(/&Igrave;/ig,"");
		strURLText = strURLText.replace(/&#204;/ig,"");
		strURLText = strURLText.replace(/&Iacute;/ig,"");
		strURLText = strURLText.replace(/&#205;/ig,"");
		strURLText = strURLText.replace(/&Icirc;/ig,"");
		strURLText = strURLText.replace(/&#206;/ig,"");
		strURLText = strURLText.replace(/&Iuml;/ig,"");
		strURLText = strURLText.replace(/&#207;/ig,"");
		strURLText = strURLText.replace(/&ETH;/ig,"");
		strURLText = strURLText.replace(/&#208;/ig,"");
		strURLText = strURLText.replace(/&Ntilde;/ig,"");
		strURLText = strURLText.replace(/&#209;/ig,"");
		strURLText = strURLText.replace(/&Ograve;/ig,"");
		strURLText = strURLText.replace(/&#210;/ig,"");	
		strURLText = strURLText.replace(/&Oacute;/ig,"");
		strURLText = strURLText.replace(/&#211;/ig,"");
		strURLText = strURLText.replace(/&Ocirc;/ig,"");
		strURLText = strURLText.replace(/&#212;/ig,"");
		strURLText = strURLText.replace(/&Otilde;/ig,"");
		strURLText = strURLText.replace(/&#213;/ig,"");
		strURLText = strURLText.replace(/&Ouml;/ig,"");
		strURLText = strURLText.replace(/&#214;/ig,"");
		strURLText = strURLText.replace(/&times;/ig,"");
		strURLText = strURLText.replace(/&#215;/ig,"");
		strURLText = strURLText.replace(/&Oslash;/ig,"");
		strURLText = strURLText.replace(/&#216;/ig,"");
		strURLText = strURLText.replace(/&Ugrave;/ig,"");
		strURLText = strURLText.replace(/&#217;/ig,"");
		strURLText = strURLText.replace(/&Uacute;/ig,"");
		strURLText = strURLText.replace(/&#218;/ig,"");
		strURLText = strURLText.replace(/&Ucirc;/ig,"");
		strURLText = strURLText.replace(/&#219;/ig,"");	
		strURLText = strURLText.replace(/&Uuml;/ig,"");
		strURLText = strURLText.replace(/&#220;/ig,"");
		strURLText = strURLText.replace(/&Yacute;/ig,"");
		strURLText = strURLText.replace(/&#221;/ig,"");
		strURLText = strURLText.replace(/&THORN;/ig,"");
		strURLText = strURLText.replace(/&#222;/ig,"");
		strURLText = strURLText.replace(/&szlig;/ig,"");
		strURLText = strURLText.replace(/&#223;/ig,"");
		strURLText = strURLText.replace(/&agrave;/ig,"");
		strURLText = strURLText.replace(/&#224;/ig,"");
		strURLText = strURLText.replace(/&aacute;/ig,"");
		strURLText = strURLText.replace(/&#225;/ig,"");
		strURLText = strURLText.replace(/&acirc;/ig,"");
		strURLText = strURLText.replace(/&#226;/ig,"");
		strURLText = strURLText.replace(/&atilde;/ig,"");
		strURLText = strURLText.replace(/&#227;/ig,"");
		strURLText = strURLText.replace(/&auml;/ig,"");
		strURLText = strURLText.replace(/&#228;/ig,"");
		strURLText = strURLText.replace(/&aring;/ig,"");
		strURLText = strURLText.replace(/&#229;/ig,"");
		strURLText = strURLText.replace(/&aelig;/ig,"");
		strURLText = strURLText.replace(/&#230;/ig,"");
		strURLText = strURLText.replace(/&ccedil;/ig,"");
		strURLText = strURLText.replace(/&#231;/ig,"");
		strURLText = strURLText.replace(/&egrave;/ig,"");
		strURLText = strURLText.replace(/&#232;/ig,"");
		strURLText = strURLText.replace(/&eacute;/ig,"");
		strURLText = strURLText.replace(/&#233;/ig,"");
		strURLText = strURLText.replace(/&ecirc;/ig,"");
		strURLText = strURLText.replace(/&#234;/ig,"");
		strURLText = strURLText.replace(/&euml;/ig,"");
		strURLText = strURLText.replace(/&#235;/ig,"");
		strURLText = strURLText.replace(/&igrave;/ig,"");
		strURLText = strURLText.replace(/&#236;/ig,"");
		strURLText = strURLText.replace(/&iacute;/ig,"");
		strURLText = strURLText.replace(/&#237;/ig,"");
		strURLText = strURLText.replace(/&icirc;/ig,"");
		strURLText = strURLText.replace(/&#238;/ig,"");
		strURLText = strURLText.replace(/&iuml;/ig,"");
		strURLText = strURLText.replace(/&#239;/ig,"");
		strURLText = strURLText.replace(/&eth;/ig,"");
		strURLText = strURLText.replace(/&#240;/ig,"");
		strURLText = strURLText.replace(/&ntilde;/ig,"");
		strURLText = strURLText.replace(/&#241;/ig,"");
		strURLText = strURLText.replace(/&ograve;/ig,"");
		strURLText = strURLText.replace(/&#242;/ig,"");
		strURLText = strURLText.replace(/&oacute;/ig,"");
		strURLText = strURLText.replace(/&#243;/ig,"");
		strURLText = strURLText.replace(/&ocirc;/ig,"");
		strURLText = strURLText.replace(/&#244;/ig,"");
		strURLText = strURLText.replace(/&otilde;/ig,"");
		strURLText = strURLText.replace(/&#245;/ig,"");
		strURLText = strURLText.replace(/&ouml;/ig,"");
		strURLText = strURLText.replace(/&#246;/ig,"");
		strURLText = strURLText.replace(/&divide;/ig,"");
		strURLText = strURLText.replace(/&#247;/ig,"");
		strURLText = strURLText.replace(/&oslash;/ig,"");
		strURLText = strURLText.replace(/&#248;/ig,"");
		strURLText = strURLText.replace(/&ugrave;/ig,"");
		strURLText = strURLText.replace(/&#249;/ig,"");
		strURLText = strURLText.replace(/&uacute;/ig,"");
		strURLText = strURLText.replace(/&#250;/ig,"");
		strURLText = strURLText.replace(/&ucirc;/ig,"");
		strURLText = strURLText.replace(/&#251;/ig,"");
		strURLText = strURLText.replace(/&uuml;/ig,"");
		strURLText = strURLText.replace(/&#252;/ig,"");
		strURLText = strURLText.replace(/&yacute;/ig,"");
		strURLText = strURLText.replace(/&#253;/ig,"");
		strURLText = strURLText.replace(/&thorn;/ig,"");
		strURLText = strURLText.replace(/&#254;/ig,"");
		strURLText = strURLText.replace(/&yuml;/ig,"");
		strURLText = strURLText.replace(/&#255;/ig,"");
	}
	return strURLText;
}

function openMyUrl( )
{
    if (this.href)
	{
		openURL(this.href );
	}
}
